# agilicus-api
Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer). 

The `agilicus_api` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2022.03.01
- Package version: 1.142.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.agilicus.com/api](https://www.agilicus.com/api)

## Requirements.

Python >= 3.6

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with agilicus-api,
you can run the following:

```python

import time
import agilicus_api
from pprint import pprint
from agilicus_api.api import application_services_api
from agilicus_api.model.application_service import ApplicationService
from agilicus_api.model.desktop_client_configuration import DesktopClientConfiguration
from agilicus_api.model.desktop_resource import DesktopResource
from agilicus_api.model.error_message import ErrorMessage
from agilicus_api.model.file_share_service import FileShareService
from agilicus_api.model.list_application_services_response import ListApplicationServicesResponse
from agilicus_api.model.list_desktop_resources_response import ListDesktopResourcesResponse
from agilicus_api.model.list_file_share_services_response import ListFileShareServicesResponse
from agilicus_api.model.list_service_forwarders_response import ListServiceForwardersResponse
from agilicus_api.model.raw_token import RawToken
from agilicus_api.model.service_forwarder import ServiceForwarder
from agilicus_api.model.usage_metric import UsageMetric
# Defining the host is optional and defaults to https://api.agilicus.com
# See configuration.py for a list of all supported configuration parameters.
configuration = agilicus_api.Configuration(
    host = "https://api.agilicus.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): token-valid
configuration = agilicus_api.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with agilicus_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = application_services_api.ApplicationServicesApi(api_client)
    application_service = ApplicationService(
        name="my-local-service",
        org_id="org_id_example",
        hostname="db.example.com",
        ipv4_addresses=[
            "192.0.2.1",
        ],
        name_resolution="static",
        config=NetworkServiceConfig(
            ports=[
                NetworkPortRange(
                    protocol="tcp",
                    port=NetworkPort("5005-5010"),
                ),
            ],
        ),
        port=1,
        protocol="tcp",
        assignments=[
            ApplicationServiceAssignment(
                app_id="app_id_example",
                environment_name="environment_name_example",
                org_id="org_id_example",
            ),
        ],
        service_type="vpn",
        tls_enabled=True,
        tls_verify=True,
        connector_id="123",
        stats=ApplicationServiceStats(),
    ) # ApplicationService | 

    try:
        # Create an ApplicationService
        api_response = api_instance.create_application_service(application_service)
        pprint(api_response)
    except agilicus_api.ApiException as e:
        print("Exception when calling ApplicationServicesApi->create_application_service: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.agilicus.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationServicesApi* | [**create_application_service**](agilicus_api/docs/ApplicationServicesApi.md#create_application_service) | **POST** /v2/application_services | Create an ApplicationService
*ApplicationServicesApi* | [**create_application_service_token**](agilicus_api/docs/ApplicationServicesApi.md#create_application_service_token) | **POST** /v2/application_services/{app_service_id}/token | create a token for an application service
*ApplicationServicesApi* | [**create_client_configuration**](agilicus_api/docs/ApplicationServicesApi.md#create_client_configuration) | **POST** /v1/desktop_resources/{resource_id}/client_configurations | Create a client configuration
*ApplicationServicesApi* | [**create_desktop_resource**](agilicus_api/docs/ApplicationServicesApi.md#create_desktop_resource) | **POST** /v1/desktop_resources | Create a DesktopResource
*ApplicationServicesApi* | [**create_file_share_service**](agilicus_api/docs/ApplicationServicesApi.md#create_file_share_service) | **POST** /v1/file_share_services | Create an FileShareService
*ApplicationServicesApi* | [**create_service_forwarder**](agilicus_api/docs/ApplicationServicesApi.md#create_service_forwarder) | **POST** /v1/service_forwarders | Create an ServiceForwarder
*ApplicationServicesApi* | [**delete_application_service**](agilicus_api/docs/ApplicationServicesApi.md#delete_application_service) | **DELETE** /v2/application_services/{app_service_id} | Remove an ApplicationService
*ApplicationServicesApi* | [**delete_desktop_resource**](agilicus_api/docs/ApplicationServicesApi.md#delete_desktop_resource) | **DELETE** /v1/desktop_resources/{resource_id} | Remove a DesktopResource
*ApplicationServicesApi* | [**delete_file_share_service**](agilicus_api/docs/ApplicationServicesApi.md#delete_file_share_service) | **DELETE** /v1/file_share_services/{file_share_service_id} | Remove an FileShareService
*ApplicationServicesApi* | [**delete_service_forwarder**](agilicus_api/docs/ApplicationServicesApi.md#delete_service_forwarder) | **DELETE** /v1/service_forwarders/{service_forwarder_id} | Remove an ServiceForwarder
*ApplicationServicesApi* | [**get_application_service**](agilicus_api/docs/ApplicationServicesApi.md#get_application_service) | **GET** /v2/application_services/{app_service_id} | Get a single ApplicationService
*ApplicationServicesApi* | [**get_application_service_usage_metrics**](agilicus_api/docs/ApplicationServicesApi.md#get_application_service_usage_metrics) | **GET** /v2/application_services/usage_metrics | Get application service metrics
*ApplicationServicesApi* | [**get_desktop_resource**](agilicus_api/docs/ApplicationServicesApi.md#get_desktop_resource) | **GET** /v1/desktop_resources/{resource_id} | Get a single DesktopResource
*ApplicationServicesApi* | [**get_file_share_service**](agilicus_api/docs/ApplicationServicesApi.md#get_file_share_service) | **GET** /v1/file_share_services/{file_share_service_id} | Get a single FileShareService
*ApplicationServicesApi* | [**get_file_share_usage_metrics**](agilicus_api/docs/ApplicationServicesApi.md#get_file_share_usage_metrics) | **GET** /v1/file_share_services/usage_metrics | Get file share service metrics
*ApplicationServicesApi* | [**get_service_forwarder**](agilicus_api/docs/ApplicationServicesApi.md#get_service_forwarder) | **GET** /v1/service_forwarders/{service_forwarder_id} | Get a single ServiceForwarder
*ApplicationServicesApi* | [**list_application_services**](agilicus_api/docs/ApplicationServicesApi.md#list_application_services) | **GET** /v2/application_services | Get a subset of the ApplicationServices
*ApplicationServicesApi* | [**list_desktop_resources**](agilicus_api/docs/ApplicationServicesApi.md#list_desktop_resources) | **GET** /v1/desktop_resources | Get a subset of the DesktopResource objects.
*ApplicationServicesApi* | [**list_file_share_services**](agilicus_api/docs/ApplicationServicesApi.md#list_file_share_services) | **GET** /v1/file_share_services | Get a subset of the FileShareServices
*ApplicationServicesApi* | [**list_service_forwarders**](agilicus_api/docs/ApplicationServicesApi.md#list_service_forwarders) | **GET** /v1/service_forwarders | Get a subset of the ServiceForwarder objects
*ApplicationServicesApi* | [**replace_application_service**](agilicus_api/docs/ApplicationServicesApi.md#replace_application_service) | **PUT** /v2/application_services/{app_service_id} | Create or update an Application Service.
*ApplicationServicesApi* | [**replace_desktop_resource**](agilicus_api/docs/ApplicationServicesApi.md#replace_desktop_resource) | **PUT** /v1/desktop_resources/{resource_id} | Create or update a DesktopResource.
*ApplicationServicesApi* | [**replace_file_share_service**](agilicus_api/docs/ApplicationServicesApi.md#replace_file_share_service) | **PUT** /v1/file_share_services/{file_share_service_id} | Create or update an FileShareService.
*ApplicationServicesApi* | [**replace_service_forwarder**](agilicus_api/docs/ApplicationServicesApi.md#replace_service_forwarder) | **PUT** /v1/service_forwarders/{service_forwarder_id} | Create or update an ServiceForwarder.
*ApplicationsApi* | [**add_config**](agilicus_api/docs/ApplicationsApi.md#add_config) | **POST** /v2/applications/{app_id}/environments/{env_name}/configs | Add an environment configuration row
*ApplicationsApi* | [**add_role**](agilicus_api/docs/ApplicationsApi.md#add_role) | **POST** /v2/applications/{app_id}/roles | Add a role to the application.
*ApplicationsApi* | [**add_role_to_rule_entry**](agilicus_api/docs/ApplicationsApi.md#add_role_to_rule_entry) | **POST** /v2/applications/{app_id}/role_to_rule_entries | Add a rule to a role in the application.
*ApplicationsApi* | [**add_rule**](agilicus_api/docs/ApplicationsApi.md#add_rule) | **POST** /v2/applications/{app_id}/rules | Add a rule to the application.
*ApplicationsApi* | [**create_application**](agilicus_api/docs/ApplicationsApi.md#create_application) | **POST** /v2/applications | Create an application
*ApplicationsApi* | [**delete_application**](agilicus_api/docs/ApplicationsApi.md#delete_application) | **DELETE** /v2/applications/{app_id} | Remove an application
*ApplicationsApi* | [**delete_config**](agilicus_api/docs/ApplicationsApi.md#delete_config) | **DELETE** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Remove an environment configuration
*ApplicationsApi* | [**delete_role**](agilicus_api/docs/ApplicationsApi.md#delete_role) | **DELETE** /v2/applications/{app_id}/roles/{role_id} | Remove a role
*ApplicationsApi* | [**delete_role_to_rule_entry**](agilicus_api/docs/ApplicationsApi.md#delete_role_to_rule_entry) | **DELETE** /v2/applications/{app_id}/role_to_rule_entries/{role_to_rule_entry_id} | Remove a role_to_rule_entry
*ApplicationsApi* | [**delete_rule**](agilicus_api/docs/ApplicationsApi.md#delete_rule) | **DELETE** /v2/applications/{app_id}/rules/{rule_id} | Remove a rule
*ApplicationsApi* | [**get_all_usage_metrics**](agilicus_api/docs/ApplicationsApi.md#get_all_usage_metrics) | **GET** /v1/resources/usage_metrics | Get all resource metrics for the Applications API
*ApplicationsApi* | [**get_application**](agilicus_api/docs/ApplicationsApi.md#get_application) | **GET** /v2/applications/{app_id} | Get a application
*ApplicationsApi* | [**get_application_usage_metrics**](agilicus_api/docs/ApplicationsApi.md#get_application_usage_metrics) | **GET** /v2/applications/usage_metrics | Get application metrics
*ApplicationsApi* | [**get_config**](agilicus_api/docs/ApplicationsApi.md#get_config) | **GET** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Get environment configuration
*ApplicationsApi* | [**get_environment**](agilicus_api/docs/ApplicationsApi.md#get_environment) | **GET** /v2/applications/{app_id}/environments/{env_name} | Get an environment
*ApplicationsApi* | [**get_role**](agilicus_api/docs/ApplicationsApi.md#get_role) | **GET** /v2/applications/{app_id}/roles/{role_id} | Get a role
*ApplicationsApi* | [**get_role_to_rule_entry**](agilicus_api/docs/ApplicationsApi.md#get_role_to_rule_entry) | **GET** /v2/applications/{app_id}/role_to_rule_entries/{role_to_rule_entry_id} | Get a role_to_rule_entry
*ApplicationsApi* | [**get_rule**](agilicus_api/docs/ApplicationsApi.md#get_rule) | **GET** /v2/applications/{app_id}/rules/{rule_id} | Get a rule
*ApplicationsApi* | [**list_application_summaries**](agilicus_api/docs/ApplicationsApi.md#list_application_summaries) | **GET** /v2/application_summaries | List application summaries
*ApplicationsApi* | [**list_applications**](agilicus_api/docs/ApplicationsApi.md#list_applications) | **GET** /v2/applications | Get applications
*ApplicationsApi* | [**list_combined_rules**](agilicus_api/docs/ApplicationsApi.md#list_combined_rules) | **GET** /v2/combined_rules | List rules combined by scope or role
*ApplicationsApi* | [**list_configs**](agilicus_api/docs/ApplicationsApi.md#list_configs) | **GET** /v2/applications/{app_id}/environments/{env_name}/configs | Get all environment configuration
*ApplicationsApi* | [**list_environment_configs_all_apps**](agilicus_api/docs/ApplicationsApi.md#list_environment_configs_all_apps) | **GET** /v2/environment_configs | Get all environment configuration for a given organisation.
*ApplicationsApi* | [**list_role_to_rule_entries**](agilicus_api/docs/ApplicationsApi.md#list_role_to_rule_entries) | **GET** /v2/applications/{app_id}/role_to_rule_entries | Get all RoleToRuleEntries
*ApplicationsApi* | [**list_roles**](agilicus_api/docs/ApplicationsApi.md#list_roles) | **GET** /v2/applications/{app_id}/roles | Get all roles
*ApplicationsApi* | [**list_rules**](agilicus_api/docs/ApplicationsApi.md#list_rules) | **GET** /v2/applications/{app_id}/rules | Get all rules
*ApplicationsApi* | [**list_runtime_status**](agilicus_api/docs/ApplicationsApi.md#list_runtime_status) | **GET** /v2/applications/{app_id}/environments/{env_name}/status/runtime_status | Get an environment&#39;s runtime status
*ApplicationsApi* | [**replace_application**](agilicus_api/docs/ApplicationsApi.md#replace_application) | **PUT** /v2/applications/{app_id} | Create or update an application
*ApplicationsApi* | [**replace_config**](agilicus_api/docs/ApplicationsApi.md#replace_config) | **PUT** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Update environment configuration
*ApplicationsApi* | [**replace_environment**](agilicus_api/docs/ApplicationsApi.md#replace_environment) | **PUT** /v2/applications/{app_id}/environments/{env_name} | Update an environment
*ApplicationsApi* | [**replace_role**](agilicus_api/docs/ApplicationsApi.md#replace_role) | **PUT** /v2/applications/{app_id}/roles/{role_id} | Update a role
*ApplicationsApi* | [**replace_role_to_rule_entry**](agilicus_api/docs/ApplicationsApi.md#replace_role_to_rule_entry) | **PUT** /v2/applications/{app_id}/role_to_rule_entries/{role_to_rule_entry_id} | Update a role_to_rule_entry
*ApplicationsApi* | [**replace_rule**](agilicus_api/docs/ApplicationsApi.md#replace_rule) | **PUT** /v2/applications/{app_id}/rules/{rule_id} | Update a rule
*ApplicationsApi* | [**replace_runtime_status**](agilicus_api/docs/ApplicationsApi.md#replace_runtime_status) | **PUT** /v2/applications/{app_id}/environments/{env_name}/status/runtime_status | update an environemnt&#39;s runtime status
*ApplicationsApi* | [**update_patch_application**](agilicus_api/docs/ApplicationsApi.md#update_patch_application) | **PATCH** /v2/applications/{app_id} | patch application
*AuditsApi* | [**bulk_create_events**](agilicus_api/docs/AuditsApi.md#bulk_create_events) | **POST** /v1/bulk_audit_events | Process an AuditWebhookBulkEvent
*AuditsApi* | [**create_audit_destination**](agilicus_api/docs/AuditsApi.md#create_audit_destination) | **POST** /v1/audit_destinations | Create an AuditDestination
*AuditsApi* | [**delete_audit_destination**](agilicus_api/docs/AuditsApi.md#delete_audit_destination) | **DELETE** /v1/audit_destinations/{destination_id} | Remove an AuditDestination
*AuditsApi* | [**get_audit_destination**](agilicus_api/docs/AuditsApi.md#get_audit_destination) | **GET** /v1/audit_destinations/{destination_id} | Get a single AuditDestination
*AuditsApi* | [**list_audit_destinations**](agilicus_api/docs/AuditsApi.md#list_audit_destinations) | **GET** /v1/audit_destinations | View audit destinations
*AuditsApi* | [**list_audits**](agilicus_api/docs/AuditsApi.md#list_audits) | **GET** /v1/audits | View audit records
*AuditsApi* | [**list_auth_records**](agilicus_api/docs/AuditsApi.md#list_auth_records) | **GET** /v1/auth_audits | View authentication audit records
*AuditsApi* | [**replace_audit_destination**](agilicus_api/docs/AuditsApi.md#replace_audit_destination) | **PUT** /v1/audit_destinations/{destination_id} | Create or update a AuditDestination.
*BillingApi* | [**add_billing_usage_record**](agilicus_api/docs/BillingApi.md#add_billing_usage_record) | **POST** /v1/billing_accounts/{billing_account_id}/usage_records | Add usage records for a billing account
*BillingApi* | [**add_org_to_billing_account**](agilicus_api/docs/BillingApi.md#add_org_to_billing_account) | **POST** /v1/billing_accounts/{billing_account_id}/orgs | Add an org to a billing account
*BillingApi* | [**create_billing_account**](agilicus_api/docs/BillingApi.md#create_billing_account) | **POST** /v1/billing_accounts | Create a billing account
*BillingApi* | [**create_product**](agilicus_api/docs/BillingApi.md#create_product) | **POST** /v1/products | Create a product
*BillingApi* | [**delete_billing_account**](agilicus_api/docs/BillingApi.md#delete_billing_account) | **DELETE** /v1/billing_accounts/{billing_account_id} | Delete a billing account
*BillingApi* | [**delete_product**](agilicus_api/docs/BillingApi.md#delete_product) | **DELETE** /v1/products/{product_id} | Delete a product
*BillingApi* | [**get_billing_account**](agilicus_api/docs/BillingApi.md#get_billing_account) | **GET** /v1/billing_accounts/{billing_account_id} | Get a single billing account
*BillingApi* | [**get_billing_account_orgs**](agilicus_api/docs/BillingApi.md#get_billing_account_orgs) | **GET** /v1/billing_accounts/{billing_account_id}/orgs | Get all orgs in a billing account
*BillingApi* | [**get_product**](agilicus_api/docs/BillingApi.md#get_product) | **GET** /v1/products/{product_id} | Get a single product
*BillingApi* | [**get_usage_records**](agilicus_api/docs/BillingApi.md#get_usage_records) | **GET** /v1/billing_accounts/{billing_account_id}/usage_records | Get all subscription usage records
*BillingApi* | [**list_billing_accounts**](agilicus_api/docs/BillingApi.md#list_billing_accounts) | **GET** /v1/billing_accounts | Get all billing accounts
*BillingApi* | [**list_products**](agilicus_api/docs/BillingApi.md#list_products) | **GET** /v1/products | Get all products
*BillingApi* | [**remove_org_from_billing_account**](agilicus_api/docs/BillingApi.md#remove_org_from_billing_account) | **DELETE** /v1/billing_accounts/{billing_account_id}/orgs/{org_id} | Remove an org from a billing account
*BillingApi* | [**replace_billing_account**](agilicus_api/docs/BillingApi.md#replace_billing_account) | **PUT** /v1/billing_accounts/{billing_account_id} | Create or update a billing account
*BillingApi* | [**replace_product**](agilicus_api/docs/BillingApi.md#replace_product) | **PUT** /v1/products/{product_id} | Create or update a product
*CataloguesApi* | [**create_catalogue**](agilicus_api/docs/CataloguesApi.md#create_catalogue) | **POST** /v1/catalogues | create a catalogue
*CataloguesApi* | [**create_catalogue_entry**](agilicus_api/docs/CataloguesApi.md#create_catalogue_entry) | **POST** /v1/catalogues/{catalogue_id}/catalogue_entries | create a catalogue entry
*CataloguesApi* | [**delete_catalogue**](agilicus_api/docs/CataloguesApi.md#delete_catalogue) | **DELETE** /v1/catalogues/{catalogue_id} | Delete the catalogue specified by catalogue_id
*CataloguesApi* | [**delete_catalogue_entry**](agilicus_api/docs/CataloguesApi.md#delete_catalogue_entry) | **DELETE** /v1/catalogues/{catalogue_id}/catalogue_entries/{catalogue_entry_id} | Delete the catalogue specified by catalogue_entry_id
*CataloguesApi* | [**get_catalogue**](agilicus_api/docs/CataloguesApi.md#get_catalogue) | **GET** /v1/catalogues/{catalogue_id} | Get the catalogue specified by catalogue_id
*CataloguesApi* | [**get_catalogue_entry**](agilicus_api/docs/CataloguesApi.md#get_catalogue_entry) | **GET** /v1/catalogues/{catalogue_id}/catalogue_entries/{catalogue_entry_id} | Get the catalogue entry by id for the given catalogue
*CataloguesApi* | [**list_all_catalogue_entries**](agilicus_api/docs/CataloguesApi.md#list_all_catalogue_entries) | **GET** /v1/catalogue_entries | List all catalogue entries independant of the catalogue they belong to
*CataloguesApi* | [**list_catalogue_entries**](agilicus_api/docs/CataloguesApi.md#list_catalogue_entries) | **GET** /v1/catalogues/{catalogue_id}/catalogue_entries | List catalogue entries in the catalogue
*CataloguesApi* | [**list_catalogues**](agilicus_api/docs/CataloguesApi.md#list_catalogues) | **GET** /v1/catalogues | List all catalogues
*CataloguesApi* | [**replace_catalogue**](agilicus_api/docs/CataloguesApi.md#replace_catalogue) | **PUT** /v1/catalogues/{catalogue_id} | Replace the catalogue specified by catalogue_id
*CataloguesApi* | [**replace_catalogue_entry**](agilicus_api/docs/CataloguesApi.md#replace_catalogue_entry) | **PUT** /v1/catalogues/{catalogue_id}/catalogue_entries/{catalogue_entry_id} | Replace the catalogue entry specified by catalogue_entry_id
*CertificatesApi* | [**create_cert**](agilicus_api/docs/CertificatesApi.md#create_cert) | **POST** /v1/certificates | Creates a X509Certificate
*CertificatesApi* | [**delete_agent_csr**](agilicus_api/docs/CertificatesApi.md#delete_agent_csr) | **DELETE** /v1/agent_connectors/{connector_id}/certificate_signing_requests/{csr_id} | Delete a CertSigningReq
*CertificatesApi* | [**delete_cert**](agilicus_api/docs/CertificatesApi.md#delete_cert) | **DELETE** /v1/certificates/{certificate_id} | Delete a X509Certificate
*CertificatesApi* | [**delete_csr**](agilicus_api/docs/CertificatesApi.md#delete_csr) | **DELETE** /v1/certificate_signing_requests/{csr_id} | Delete a CertSigningReq
*CertificatesApi* | [**get_cert**](agilicus_api/docs/CertificatesApi.md#get_cert) | **GET** /v1/certificates/{certificate_id} | Get a X509Certificate
*CertificatesApi* | [**get_csr**](agilicus_api/docs/CertificatesApi.md#get_csr) | **GET** /v1/certificate_signing_requests/{csr_id} | Get a CertSigningReq
*CertificatesApi* | [**list_certs**](agilicus_api/docs/CertificatesApi.md#list_certs) | **GET** /v1/certificates | list certificates
*CertificatesApi* | [**list_csr**](agilicus_api/docs/CertificatesApi.md#list_csr) | **GET** /v1/certificate_signing_requests | list certificate signing requests
*CertificatesApi* | [**replace_csr**](agilicus_api/docs/CertificatesApi.md#replace_csr) | **PUT** /v1/certificate_signing_requests/{csr_id} | Update a CertSigningReq
*ChallengesApi* | [**create_challenge**](agilicus_api/docs/ChallengesApi.md#create_challenge) | **POST** /v1/challenges | create a challenge
*ChallengesApi* | [**create_totp_enrollment**](agilicus_api/docs/ChallengesApi.md#create_totp_enrollment) | **POST** /v1/challenge_enrollment/totp | create a TOTP challenge enrollment
*ChallengesApi* | [**create_webauthn_enrollment**](agilicus_api/docs/ChallengesApi.md#create_webauthn_enrollment) | **POST** /v1/challenge_enrollment/webauthn | create a WebAuthN challenge enrollment
*ChallengesApi* | [**delete_challenge**](agilicus_api/docs/ChallengesApi.md#delete_challenge) | **DELETE** /v1/challenges/{challenge_id} | Delete the challenge specified by challenge_id
*ChallengesApi* | [**delete_totp_enrollment**](agilicus_api/docs/ChallengesApi.md#delete_totp_enrollment) | **DELETE** /v1/challenge_enrollment/totp/{totp_id} | Delete the TOTP enrollment specified by totp id
*ChallengesApi* | [**delete_webauthn_enrollment**](agilicus_api/docs/ChallengesApi.md#delete_webauthn_enrollment) | **DELETE** /v1/challenge_enrollment/webauthn/{webauthn_id} | Delete the WebAuthN enrollment specified by webauthn_id
*ChallengesApi* | [**get_answer**](agilicus_api/docs/ChallengesApi.md#get_answer) | **GET** /v1/challenges/{challenge_id}/answers | answer a challenge
*ChallengesApi* | [**get_challenge**](agilicus_api/docs/ChallengesApi.md#get_challenge) | **GET** /v1/challenges/{challenge_id} | Get the challenge specified by challenge_id
*ChallengesApi* | [**get_totp_enrollment**](agilicus_api/docs/ChallengesApi.md#get_totp_enrollment) | **GET** /v1/challenge_enrollment/totp/{totp_id} | Get the TOTP enrollment specified by totp_id
*ChallengesApi* | [**get_webauthn_enrollment**](agilicus_api/docs/ChallengesApi.md#get_webauthn_enrollment) | **GET** /v1/challenge_enrollment/webauthn/{webauthn_id} | Get the WebAuthN enrollment specified by webauthn_id
*ChallengesApi* | [**list_totp_enrollment**](agilicus_api/docs/ChallengesApi.md#list_totp_enrollment) | **GET** /v1/challenge_enrollment/totp | List the totp enrollment results
*ChallengesApi* | [**list_webauthn_enrollments**](agilicus_api/docs/ChallengesApi.md#list_webauthn_enrollments) | **GET** /v1/challenge_enrollment/webauthn | List the webauthn enrollments
*ChallengesApi* | [**replace_challenge**](agilicus_api/docs/ChallengesApi.md#replace_challenge) | **PUT** /v1/challenges/{challenge_id} | Replace the challenge specified by challenge_id
*ChallengesApi* | [**update_totp_enrollment**](agilicus_api/docs/ChallengesApi.md#update_totp_enrollment) | **POST** /v1/challenge_enrollment/totp/{totp_id} | Update the totp_enrollment if the answer provided is correct.
*ChallengesApi* | [**update_webauthn_enrollment**](agilicus_api/docs/ChallengesApi.md#update_webauthn_enrollment) | **POST** /v1/challenge_enrollment/webauthn/{webauthn_id} | Update the WebAuthN enrollment if the answer provided is correct.
*ConnectorsApi* | [**create_agent_connector**](agilicus_api/docs/ConnectorsApi.md#create_agent_connector) | **POST** /v1/agent_connectors | Create an agent connector
*ConnectorsApi* | [**create_agent_csr**](agilicus_api/docs/ConnectorsApi.md#create_agent_csr) | **POST** /v1/agent_connectors/{connector_id}/certificate_signing_requests | Creates a CertSigningReq
*ConnectorsApi* | [**create_agent_stats**](agilicus_api/docs/ConnectorsApi.md#create_agent_stats) | **POST** /v1/agent_connectors/{connector_id}/stats | Creates an AgentConnectorStats record.
*ConnectorsApi* | [**create_csr**](agilicus_api/docs/ConnectorsApi.md#create_csr) | **POST** /v1/certificate_signing_requests | Creates a CertSigningReq
*ConnectorsApi* | [**create_ipsec_connector**](agilicus_api/docs/ConnectorsApi.md#create_ipsec_connector) | **POST** /v1/ipsec_connectors | Create an IPsec connector
*ConnectorsApi* | [**delete_agent_connector**](agilicus_api/docs/ConnectorsApi.md#delete_agent_connector) | **DELETE** /v1/agent_connectors/{connector_id} | Delete a agent
*ConnectorsApi* | [**delete_connector**](agilicus_api/docs/ConnectorsApi.md#delete_connector) | **DELETE** /v1/connectors/{connector_id} | Delete a connector
*ConnectorsApi* | [**delete_ipsec_connector**](agilicus_api/docs/ConnectorsApi.md#delete_ipsec_connector) | **DELETE** /v1/ipsec_connectors/{connector_id} | Delete an IPsec connector
*ConnectorsApi* | [**get_agent_connector**](agilicus_api/docs/ConnectorsApi.md#get_agent_connector) | **GET** /v1/agent_connectors/{connector_id} | Get an agent
*ConnectorsApi* | [**get_agent_csr**](agilicus_api/docs/ConnectorsApi.md#get_agent_csr) | **GET** /v1/agent_connectors/{connector_id}/certificate_signing_requests/{csr_id} | Update a CertSigningReq
*ConnectorsApi* | [**get_agent_info**](agilicus_api/docs/ConnectorsApi.md#get_agent_info) | **GET** /v1/agent_connectors/{connector_id}/info | Get information associated with connector
*ConnectorsApi* | [**get_agent_stats**](agilicus_api/docs/ConnectorsApi.md#get_agent_stats) | **GET** /v1/agent_connectors/{connector_id}/stats | Get the AgentConnector stats
*ConnectorsApi* | [**get_connector**](agilicus_api/docs/ConnectorsApi.md#get_connector) | **GET** /v1/connectors/{connector_id} | Get a connector
*ConnectorsApi* | [**get_ipsec_connector**](agilicus_api/docs/ConnectorsApi.md#get_ipsec_connector) | **GET** /v1/ipsec_connectors/{connector_id} | Get an IPsec connector
*ConnectorsApi* | [**get_ipsec_connector_info**](agilicus_api/docs/ConnectorsApi.md#get_ipsec_connector_info) | **GET** /v1/ipsec_connectors/{connector_id}/info | Get IPsec connector runtime information
*ConnectorsApi* | [**list_agent_connector**](agilicus_api/docs/ConnectorsApi.md#list_agent_connector) | **GET** /v1/agent_connectors | list agent connectors
*ConnectorsApi* | [**list_agent_csr**](agilicus_api/docs/ConnectorsApi.md#list_agent_csr) | **GET** /v1/agent_connectors/{connector_id}/certificate_signing_requests | list agent connector certificate signing requests
*ConnectorsApi* | [**list_connector**](agilicus_api/docs/ConnectorsApi.md#list_connector) | **GET** /v1/connectors | List connectors
*ConnectorsApi* | [**list_ipsec_connector**](agilicus_api/docs/ConnectorsApi.md#list_ipsec_connector) | **GET** /v1/ipsec_connectors | list IPsec connectors
*ConnectorsApi* | [**replace_agent_connector**](agilicus_api/docs/ConnectorsApi.md#replace_agent_connector) | **PUT** /v1/agent_connectors/{connector_id} | Update an agent
*ConnectorsApi* | [**replace_agent_connector_local_auth_info**](agilicus_api/docs/ConnectorsApi.md#replace_agent_connector_local_auth_info) | **PUT** /v1/agent_connectors/{connector_id}/local_auth_info | Update an agent&#39;s local authentication information
*ConnectorsApi* | [**replace_agent_csr**](agilicus_api/docs/ConnectorsApi.md#replace_agent_csr) | **PUT** /v1/agent_connectors/{connector_id}/certificate_signing_requests/{csr_id} | Update a CertSigningReq
*ConnectorsApi* | [**replace_ipsec_connector**](agilicus_api/docs/ConnectorsApi.md#replace_ipsec_connector) | **PUT** /v1/ipsec_connectors/{connector_id} | Update an IPsec connector
*DiagnosticsApi* | [**list_logs**](agilicus_api/docs/DiagnosticsApi.md#list_logs) | **GET** /v1/diagnostics/logs | Retrieve application logs
*FilesApi* | [**add_file**](agilicus_api/docs/FilesApi.md#add_file) | **POST** /v1/files | upload a file
*FilesApi* | [**delete_file**](agilicus_api/docs/FilesApi.md#delete_file) | **DELETE** /v1/files/{file_id} | Delete a File
*FilesApi* | [**get_download**](agilicus_api/docs/FilesApi.md#get_download) | **GET** /v1/files_download/{file_id} | Download File
*FilesApi* | [**get_file**](agilicus_api/docs/FilesApi.md#get_file) | **GET** /v1/files/{file_id} | Get File metadata
*FilesApi* | [**list_files**](agilicus_api/docs/FilesApi.md#list_files) | **GET** /v1/files | Query Files
*FilesApi* | [**replace_file**](agilicus_api/docs/FilesApi.md#replace_file) | **PUT** /v1/files/{file_id} | Update a file
*GroupsApi* | [**add_group_member**](agilicus_api/docs/GroupsApi.md#add_group_member) | **POST** /v1/groups/{group_id}/members | Add a group member
*GroupsApi* | [**create_group**](agilicus_api/docs/GroupsApi.md#create_group) | **POST** /v1/groups | Create a group
*GroupsApi* | [**create_upstream_group_reconcile**](agilicus_api/docs/GroupsApi.md#create_upstream_group_reconcile) | **POST** /v1/groups/reconcile_upstream_groups | Reconcile a user&#39;s groups based on the user&#39;s upstream group membership
*GroupsApi* | [**create_upstream_group_reconcile_sim**](agilicus_api/docs/GroupsApi.md#create_upstream_group_reconcile_sim) | **POST** /v1/groups/simulate_reconcile_upstream_groups | Get the set of groups to reconcile based on the user&#39;s upstream group membership
*GroupsApi* | [**delete_group**](agilicus_api/docs/GroupsApi.md#delete_group) | **DELETE** /v1/groups/{group_id} | Delete a group
*GroupsApi* | [**delete_group_member**](agilicus_api/docs/GroupsApi.md#delete_group_member) | **DELETE** /v1/groups/{group_id}/members/{member_id} | Remove a group member
*GroupsApi* | [**get_group**](agilicus_api/docs/GroupsApi.md#get_group) | **GET** /v1/groups/{group_id} | Get a group
*GroupsApi* | [**list_groups**](agilicus_api/docs/GroupsApi.md#list_groups) | **GET** /v1/groups | Get all groups
*GroupsApi* | [**replace_group**](agilicus_api/docs/GroupsApi.md#replace_group) | **PUT** /v1/groups/{group_id} | update a group
*IssuersApi* | [**create_client**](agilicus_api/docs/IssuersApi.md#create_client) | **POST** /v1/clients | Create a client
*IssuersApi* | [**create_issuer**](agilicus_api/docs/IssuersApi.md#create_issuer) | **POST** /v1/issuers/issuer_roots | Create an issuer
*IssuersApi* | [**create_policy**](agilicus_api/docs/IssuersApi.md#create_policy) | **POST** /v1/issuers/authentication_policies | Create a policy
*IssuersApi* | [**create_policy_rule**](agilicus_api/docs/IssuersApi.md#create_policy_rule) | **POST** /v1/issuers/authentication_policies/{policy_id}/policy_rules | Create a policy rule
*IssuersApi* | [**create_upstream_alias**](agilicus_api/docs/IssuersApi.md#create_upstream_alias) | **POST** /v1/issuers/issuer_extensions/{issuer_id}/upstream_aliases | Create an upstream alias
*IssuersApi* | [**create_upstream_group_mapping**](agilicus_api/docs/IssuersApi.md#create_upstream_group_mapping) | **POST** /v1/issuers/issuer_extensions/{issuer_id}/upstream_group_mapping | Create an upstream group mapping
*IssuersApi* | [**delete_client**](agilicus_api/docs/IssuersApi.md#delete_client) | **DELETE** /v1/clients/{client_id} | Delete a client
*IssuersApi* | [**delete_policy**](agilicus_api/docs/IssuersApi.md#delete_policy) | **DELETE** /v1/issuers/authentication_policies/{policy_id} | Delete a Policy
*IssuersApi* | [**delete_policy_rule**](agilicus_api/docs/IssuersApi.md#delete_policy_rule) | **DELETE** /v1/issuers/authentication_policies/{policy_id}/policy_rules/{policy_rule_id} | Delete a Policy Rule
*IssuersApi* | [**delete_root**](agilicus_api/docs/IssuersApi.md#delete_root) | **DELETE** /v1/issuers/issuer_roots/{issuer_id} | Delete an Issuer
*IssuersApi* | [**delete_upstream_alias**](agilicus_api/docs/IssuersApi.md#delete_upstream_alias) | **DELETE** /v1/issuers/issuer_extensions/{issuer_id}/upstream_aliases/{upstream_alias_id} | Delete an upstream alias
*IssuersApi* | [**delete_upstream_group_mapping**](agilicus_api/docs/IssuersApi.md#delete_upstream_group_mapping) | **DELETE** /v1/issuers/issuer_extensions/{issuer_id}/upstream_group_mapping/{upstream_group_mapping_id} | Delete an upstream group mapping
*IssuersApi* | [**get_client**](agilicus_api/docs/IssuersApi.md#get_client) | **GET** /v1/clients/{client_id} | Get a client
*IssuersApi* | [**get_issuer**](agilicus_api/docs/IssuersApi.md#get_issuer) | **GET** /v1/issuers/issuer_extensions/{issuer_id} | Get an issuer
*IssuersApi* | [**get_policy**](agilicus_api/docs/IssuersApi.md#get_policy) | **GET** /v1/issuers/authentication_policies/{policy_id} | Get a policy
*IssuersApi* | [**get_policy_rule**](agilicus_api/docs/IssuersApi.md#get_policy_rule) | **GET** /v1/issuers/authentication_policies/{policy_id}/policy_rules/{policy_rule_id} | Get a policy rule
*IssuersApi* | [**get_root**](agilicus_api/docs/IssuersApi.md#get_root) | **GET** /v1/issuers/issuer_roots/{issuer_id} | Get an issuer
*IssuersApi* | [**get_upstream_alias**](agilicus_api/docs/IssuersApi.md#get_upstream_alias) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/upstream_aliases/{upstream_alias_id} | Get an upstream alias
*IssuersApi* | [**get_upstream_group_mapping**](agilicus_api/docs/IssuersApi.md#get_upstream_group_mapping) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/upstream_group_mapping/{upstream_group_mapping_id} | Get an upstream group mapping
*IssuersApi* | [**get_upstreams**](agilicus_api/docs/IssuersApi.md#get_upstreams) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/upstreams | Get provisioned upstreams for the issuer
*IssuersApi* | [**get_wellknown_issuer_info**](agilicus_api/docs/IssuersApi.md#get_wellknown_issuer_info) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/well_known_info | Get well-known issuer information
*IssuersApi* | [**list_clients**](agilicus_api/docs/IssuersApi.md#list_clients) | **GET** /v1/clients | Query Clients
*IssuersApi* | [**list_issuer_roots**](agilicus_api/docs/IssuersApi.md#list_issuer_roots) | **GET** /v1/issuers/issuer_roots | Query Issuers
*IssuersApi* | [**list_issuer_upstreams**](agilicus_api/docs/IssuersApi.md#list_issuer_upstreams) | **GET** /v1/issuer_upstreams | list issuer upstream information
*IssuersApi* | [**list_issuers**](agilicus_api/docs/IssuersApi.md#list_issuers) | **GET** /v1/issuers/issuer_extensions | Query Issuers
*IssuersApi* | [**list_policies**](agilicus_api/docs/IssuersApi.md#list_policies) | **GET** /v1/issuers/authentication_policies | Query Policies
*IssuersApi* | [**list_policy_rules**](agilicus_api/docs/IssuersApi.md#list_policy_rules) | **GET** /v1/issuers/authentication_policies/{policy_id}/policy_rules | Query Policy rules
*IssuersApi* | [**list_upstream_aliases**](agilicus_api/docs/IssuersApi.md#list_upstream_aliases) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/upstream_aliases | Query upstream aliases for an issuer
*IssuersApi* | [**list_upstream_group_mappings**](agilicus_api/docs/IssuersApi.md#list_upstream_group_mappings) | **GET** /v1/issuers/issuer_extensions/{issuer_id}/upstream_group_mapping | Query upstream group mappings for an issuer
*IssuersApi* | [**list_wellknown_issuer_info**](agilicus_api/docs/IssuersApi.md#list_wellknown_issuer_info) | **GET** /v1/issuers/issuer_extensions/well_known_info | list well-known issuer information
*IssuersApi* | [**replace_client**](agilicus_api/docs/IssuersApi.md#replace_client) | **PUT** /v1/clients/{client_id} | Update a client
*IssuersApi* | [**replace_issuer**](agilicus_api/docs/IssuersApi.md#replace_issuer) | **PUT** /v1/issuers/issuer_extensions/{issuer_id} | Update an issuer
*IssuersApi* | [**replace_policy**](agilicus_api/docs/IssuersApi.md#replace_policy) | **PUT** /v1/issuers/authentication_policies/{policy_id} | Update a policy
*IssuersApi* | [**replace_policy_rule**](agilicus_api/docs/IssuersApi.md#replace_policy_rule) | **PUT** /v1/issuers/authentication_policies/{policy_id}/policy_rules/{policy_rule_id} | Update a policy rule
*IssuersApi* | [**replace_root**](agilicus_api/docs/IssuersApi.md#replace_root) | **PUT** /v1/issuers/issuer_roots/{issuer_id} | Update an issuer
*IssuersApi* | [**replace_upstream_alias**](agilicus_api/docs/IssuersApi.md#replace_upstream_alias) | **PUT** /v1/issuers/issuer_extensions/{issuer_id}/upstream_aliases/{upstream_alias_id} | Update an upstream alias
*IssuersApi* | [**replace_upstream_group_mapping**](agilicus_api/docs/IssuersApi.md#replace_upstream_group_mapping) | **PUT** /v1/issuers/issuer_extensions/{issuer_id}/upstream_group_mapping/{upstream_group_mapping_id} | Update an upstream group mapping
*IssuersApi* | [**reset_service_account**](agilicus_api/docs/IssuersApi.md#reset_service_account) | **POST** /v1/issuers/reset_service_account | Reset the service account for the specified issuer
*IssuersApi* | [**reset_to_default_policy**](agilicus_api/docs/IssuersApi.md#reset_to_default_policy) | **POST** /v1/issuers/issuer_extensions/{issuer_id}/set_auth_policy_to_default | Reset the current policy to the default policy
*IssuersApi* | [**set_policy**](agilicus_api/docs/IssuersApi.md#set_policy) | **POST** /v1/issuers/issuer_extensions/{issuer_id}/set_auth_policy | Set the current policy to the policy sent
*LaunchersApi* | [**create_launcher**](agilicus_api/docs/LaunchersApi.md#create_launcher) | **POST** /v1/launchers | Create a launcher
*LaunchersApi* | [**delete_launcher**](agilicus_api/docs/LaunchersApi.md#delete_launcher) | **DELETE** /v1/launchers/{launcher_id} | Delete a Launcher
*LaunchersApi* | [**get_launcher**](agilicus_api/docs/LaunchersApi.md#get_launcher) | **GET** /v1/launchers/{launcher_id} | Get a single launcher
*LaunchersApi* | [**list_launchers**](agilicus_api/docs/LaunchersApi.md#list_launchers) | **GET** /v1/launchers | Get all launchers
*LaunchersApi* | [**replace_launcher**](agilicus_api/docs/LaunchersApi.md#replace_launcher) | **PUT** /v1/launchers/{launcher_id} | Create or update a launcher
*MessagesApi* | [**create_message**](agilicus_api/docs/MessagesApi.md#create_message) | **POST** /v1/messages/{message_endpoint_id}/send | Send a message to a specific message endpoint.
*MessagesApi* | [**create_user_message**](agilicus_api/docs/MessagesApi.md#create_user_message) | **POST** /v1/messages/user/{user_id}/send | Send a message to a user on all (optionally of a type) endpoints.
*MessagesApi* | [**delete_message_endpoint**](agilicus_api/docs/MessagesApi.md#delete_message_endpoint) | **DELETE** /v1/messages/{message_endpoint_id} | Delete a messaging endpoint
*MessagesApi* | [**get_message_endpoint**](agilicus_api/docs/MessagesApi.md#get_message_endpoint) | **GET** /v1/messages/{message_endpoint_id} | Get a message endpoint
*MessagesApi* | [**list_message_endpoints**](agilicus_api/docs/MessagesApi.md#list_message_endpoints) | **GET** /v1/messages | List all message endpoints (all users or a single user)
*MessagesApi* | [**list_messages_config**](agilicus_api/docs/MessagesApi.md#list_messages_config) | **GET** /v1/messages/config | Get the config of the endpoint-types (e.g. public keys etc).
*MessagesApi* | [**replace_message_endpoint**](agilicus_api/docs/MessagesApi.md#replace_message_endpoint) | **PUT** /v1/messages/{message_endpoint_id} | Update a messaging endpoint
*MessagesApi* | [**update_message_endpoint**](agilicus_api/docs/MessagesApi.md#update_message_endpoint) | **POST** /v1/messages/register/{user_id} | Register a messaging endpoint on a user.
*MetricsApi* | [**list_active_users**](agilicus_api/docs/MetricsApi.md#list_active_users) | **GET** /v1/metrics/{org_id}/active_users | View number of active users
*MetricsApi* | [**list_top_users**](agilicus_api/docs/MetricsApi.md#list_top_users) | **GET** /v1/metrics/{org_id}/top_users | View top users
*OrganisationsApi* | [**create_billing_portal_link**](agilicus_api/docs/OrganisationsApi.md#create_billing_portal_link) | **POST** /v1/orgs/{org_id}/billing_portal_links | Create a link to the billing portal
*OrganisationsApi* | [**create_blocking_upgrade_orgs_task**](agilicus_api/docs/OrganisationsApi.md#create_blocking_upgrade_orgs_task) | **POST** /v1/orgs/upgrade | utility to upgrade organisations
*OrganisationsApi* | [**create_org**](agilicus_api/docs/OrganisationsApi.md#create_org) | **POST** /v1/orgs | Create an organisation
*OrganisationsApi* | [**create_sub_org**](agilicus_api/docs/OrganisationsApi.md#create_sub_org) | **POST** /v1/orgs/{org_id}/orgs | Create a sub organisation
*OrganisationsApi* | [**delete_sub_org**](agilicus_api/docs/OrganisationsApi.md#delete_sub_org) | **DELETE** /v1/orgs/{org_id}/orgs/{sub_org_id} | Delete a sub organisation
*OrganisationsApi* | [**get_org**](agilicus_api/docs/OrganisationsApi.md#get_org) | **GET** /v1/orgs/{org_id} | Get a single organisation
*OrganisationsApi* | [**get_org_billing_account**](agilicus_api/docs/OrganisationsApi.md#get_org_billing_account) | **GET** /v1/orgs/{org_id}/billing_account | Get the billing account associated with the organisation
*OrganisationsApi* | [**get_org_status**](agilicus_api/docs/OrganisationsApi.md#get_org_status) | **GET** /v1/orgs/{org_id}/status | Get the status of an organisation
*OrganisationsApi* | [**get_usage_metrics**](agilicus_api/docs/OrganisationsApi.md#get_usage_metrics) | **GET** /v1/orgs/usage_metrics | Get all usage metrics for an organisation
*OrganisationsApi* | [**list_email_domains**](agilicus_api/docs/OrganisationsApi.md#list_email_domains) | **GET** /v1/orgs/{org_id}/domains | List all unique email domains for users that are inside an organisation
*OrganisationsApi* | [**list_orgs**](agilicus_api/docs/OrganisationsApi.md#list_orgs) | **GET** /v1/orgs | Get all organisations
*OrganisationsApi* | [**list_sub_orgs**](agilicus_api/docs/OrganisationsApi.md#list_sub_orgs) | **GET** /v1/orgs/{org_id}/orgs | Get all sub organisations
*OrganisationsApi* | [**replace_org**](agilicus_api/docs/OrganisationsApi.md#replace_org) | **PUT** /v1/orgs/{org_id} | Create or update an organisation
*PermissionsApi* | [**bulk_delete_resource_permission**](agilicus_api/docs/PermissionsApi.md#bulk_delete_resource_permission) | **DELETE** /v1/resource_permissions | Delete a set of resource permissions matching the resource id
*PermissionsApi* | [**create_resource_permission**](agilicus_api/docs/PermissionsApi.md#create_resource_permission) | **POST** /v1/resource_permissions | Create a ResourcePermission
*PermissionsApi* | [**create_resource_role**](agilicus_api/docs/PermissionsApi.md#create_resource_role) | **POST** /v1/resources/{resource_type}/roles | Create a ResourceRole
*PermissionsApi* | [**delete_resource_permission**](agilicus_api/docs/PermissionsApi.md#delete_resource_permission) | **DELETE** /v1/resource_permissions/{resource_permission_id} | Delete a ResourcePermission
*PermissionsApi* | [**delete_resource_role**](agilicus_api/docs/PermissionsApi.md#delete_resource_role) | **DELETE** /v1/resources/{resource_type}/roles/{role_name} | Delete a ResourceRole
*PermissionsApi* | [**get_elevated_user_roles**](agilicus_api/docs/PermissionsApi.md#get_elevated_user_roles) | **GET** /v1/elevated_permissions/{user_id} | Get elevated roles for a user
*PermissionsApi* | [**get_resource_permission**](agilicus_api/docs/PermissionsApi.md#get_resource_permission) | **GET** /v1/resource_permissions/{resource_permission_id} | Get a ResourcePermission
*PermissionsApi* | [**get_resource_role**](agilicus_api/docs/PermissionsApi.md#get_resource_role) | **GET** /v1/resources/{resource_type}/roles/{role_name} | Get a ResourceRole
*PermissionsApi* | [**list_elevated_user_roles**](agilicus_api/docs/PermissionsApi.md#list_elevated_user_roles) | **GET** /v1/elevated_permissions | List all elevated users and their roles
*PermissionsApi* | [**list_resource_permissions**](agilicus_api/docs/PermissionsApi.md#list_resource_permissions) | **GET** /v1/resource_permissions | List all ResourcePermissions
*PermissionsApi* | [**list_resource_roles**](agilicus_api/docs/PermissionsApi.md#list_resource_roles) | **GET** /v1/resource_roles | List all ResourceRoles
*PermissionsApi* | [**list_resource_roles_for_type**](agilicus_api/docs/PermissionsApi.md#list_resource_roles_for_type) | **GET** /v1/resources/{resource_type}/roles | List all ResourceRoles
*PermissionsApi* | [**replace_elevated_user_role**](agilicus_api/docs/PermissionsApi.md#replace_elevated_user_role) | **PUT** /v1/elevated_permissions/{user_id} | Create or update an elevated user role
*PermissionsApi* | [**replace_resource_permission**](agilicus_api/docs/PermissionsApi.md#replace_resource_permission) | **PUT** /v1/resource_permissions/{resource_permission_id} | Update a ResourcePermission
*PermissionsApi* | [**replace_resource_role**](agilicus_api/docs/PermissionsApi.md#replace_resource_role) | **PUT** /v1/resources/{resource_type}/roles/{role_name} | Update a ResourceRole
*PolicyApi* | [**get_challenge_decision**](agilicus_api/docs/PolicyApi.md#get_challenge_decision) | **POST** /v1/data/authentication/mfa_policy/allow | evaluate a policy challenge decision
*PolicyApi* | [**get_enrollment_decision**](agilicus_api/docs/PolicyApi.md#get_enrollment_decision) | **POST** /v1/data/authentication/enrollment/allow | evaluate a policy enrollment decision
*PolicyApi* | [**map_attributes**](agilicus_api/docs/PolicyApi.md#map_attributes) | **POST** /v1/data/authentication/attribute_mapping/map_attributes | map attributes of a user
*ResourcesApi* | [**add_resource**](agilicus_api/docs/ResourcesApi.md#add_resource) | **POST** /v1/resources | Add a resource
*ResourcesApi* | [**delete_resource**](agilicus_api/docs/ResourcesApi.md#delete_resource) | **DELETE** /v1/resources/{resource_id} | Delete a resource
*ResourcesApi* | [**get_resource**](agilicus_api/docs/ResourcesApi.md#get_resource) | **GET** /v1/resources/{resource_id} | Get a resource
*ResourcesApi* | [**list_resources**](agilicus_api/docs/ResourcesApi.md#list_resources) | **GET** /v1/resources | List all Resources
*ResourcesApi* | [**replace_resource**](agilicus_api/docs/ResourcesApi.md#replace_resource) | **PUT** /v1/resources/{resource_id} | update a resource
*TokensApi* | [**create_api_key**](agilicus_api/docs/TokensApi.md#create_api_key) | **POST** /v1/api_keys | Create an API Key
*TokensApi* | [**create_api_key_introspection**](agilicus_api/docs/TokensApi.md#create_api_key_introspection) | **POST** /v1/api_keys/introspect | Introspect an API Key
*TokensApi* | [**create_authentication_document**](agilicus_api/docs/TokensApi.md#create_authentication_document) | **POST** /v1/authentication_documents | Create a authentication document
*TokensApi* | [**create_bulk_delete_session_task**](agilicus_api/docs/TokensApi.md#create_bulk_delete_session_task) | **POST** /v1/sessions/bulk_delete | Delete a set of sessions
*TokensApi* | [**create_bulk_revoke_session_task**](agilicus_api/docs/TokensApi.md#create_bulk_revoke_session_task) | **POST** /v1/sessions/bulk_revoke | Revoke a set of sessions
*TokensApi* | [**create_bulk_revoke_token_task**](agilicus_api/docs/TokensApi.md#create_bulk_revoke_token_task) | **POST** /v1/tokens/bulk_revoke | Revoke a set of tokens
*TokensApi* | [**create_introspect_token**](agilicus_api/docs/TokensApi.md#create_introspect_token) | **POST** /v1/tokens/introspect | Introspect a token
*TokensApi* | [**create_introspect_token_all_sub_orgs**](agilicus_api/docs/TokensApi.md#create_introspect_token_all_sub_orgs) | **POST** /v1/tokens/introspect_all_sub_orgs | Introspect a token in all sub orgs
*TokensApi* | [**create_reissued_token**](agilicus_api/docs/TokensApi.md#create_reissued_token) | **POST** /v1/tokens/reissue | Issue a new token from another
*TokensApi* | [**create_revoke_token_task**](agilicus_api/docs/TokensApi.md#create_revoke_token_task) | **POST** /v1/tokens/revoke | Revoke a token
*TokensApi* | [**create_session**](agilicus_api/docs/TokensApi.md#create_session) | **POST** /v1/sessions | Create a session
*TokensApi* | [**create_session_and_token**](agilicus_api/docs/TokensApi.md#create_session_and_token) | **POST** /v1/sessions/create_session_and_token | Create a session and a token associated with the session
*TokensApi* | [**create_token**](agilicus_api/docs/TokensApi.md#create_token) | **POST** /v1/tokens | Create a token
*TokensApi* | [**create_token_validation**](agilicus_api/docs/TokensApi.md#create_token_validation) | **POST** /v1/tokens/validations | Validate a token request
*TokensApi* | [**delete_api_key**](agilicus_api/docs/TokensApi.md#delete_api_key) | **DELETE** /v1/api_keys/{api_key_id} | Delete an API Key
*TokensApi* | [**delete_authentication_document**](agilicus_api/docs/TokensApi.md#delete_authentication_document) | **DELETE** /v1/authentication_documents/{document_id} | Delete a authentication document
*TokensApi* | [**delete_session**](agilicus_api/docs/TokensApi.md#delete_session) | **DELETE** /v1/sessions/{session_id} | Delete a session
*TokensApi* | [**get_api_key**](agilicus_api/docs/TokensApi.md#get_api_key) | **GET** /v1/api_keys/{api_key_id} | Get an API Key
*TokensApi* | [**get_authentication_document**](agilicus_api/docs/TokensApi.md#get_authentication_document) | **GET** /v1/authentication_documents/{document_id} | Get a authentication document
*TokensApi* | [**get_session**](agilicus_api/docs/TokensApi.md#get_session) | **GET** /v1/sessions/{session_id} | Get a session
*TokensApi* | [**list_api_keys**](agilicus_api/docs/TokensApi.md#list_api_keys) | **GET** /v1/api_keys | List API Keys
*TokensApi* | [**list_authentication_documents**](agilicus_api/docs/TokensApi.md#list_authentication_documents) | **GET** /v1/authentication_documents | List authentication documents
*TokensApi* | [**list_sessions**](agilicus_api/docs/TokensApi.md#list_sessions) | **GET** /v1/sessions | List Sessions
*TokensApi* | [**list_tokens**](agilicus_api/docs/TokensApi.md#list_tokens) | **GET** /v1/tokens | Query tokens
*TokensApi* | [**replace_api_key**](agilicus_api/docs/TokensApi.md#replace_api_key) | **PUT** /v1/api_keys/{api_key_id} | Update an API key
*TokensApi* | [**replace_session**](agilicus_api/docs/TokensApi.md#replace_session) | **PUT** /v1/sessions/{session_id} | Update a session
*TokensApi* | [**validate_identity_assertion**](agilicus_api/docs/TokensApi.md#validate_identity_assertion) | **POST** /v1/authentication_documents_rpc/validate_identity_assertion | Validate an identity assertion
*UsersApi* | [**bulk_update_metadata**](agilicus_api/docs/UsersApi.md#bulk_update_metadata) | **POST** /v1/user_metadata_rpc/bulk_update | Update a group of user&#39;s metadata for the specified org
*UsersApi* | [**create_challenge_method**](agilicus_api/docs/UsersApi.md#create_challenge_method) | **POST** /users/{user_id}/mfa_challenge_methods | Create a multi-factor authentication method
*UsersApi* | [**create_service_account**](agilicus_api/docs/UsersApi.md#create_service_account) | **POST** /v1/service_accounts | Create a service account
*UsersApi* | [**create_upstream_user_identity**](agilicus_api/docs/UsersApi.md#create_upstream_user_identity) | **POST** /users/{user_id}/upstream_user_identities | Create an upstream user identity
*UsersApi* | [**create_user**](agilicus_api/docs/UsersApi.md#create_user) | **POST** /users | Create a user
*UsersApi* | [**create_user_identity_update**](agilicus_api/docs/UsersApi.md#create_user_identity_update) | **POST** /users/{user_id}/user_identity_updates | Update a user&#39;s core identity information.
*UsersApi* | [**create_user_metadata**](agilicus_api/docs/UsersApi.md#create_user_metadata) | **POST** /v1/user_metadata | Create a metadata entry for the user
*UsersApi* | [**create_user_request**](agilicus_api/docs/UsersApi.md#create_user_request) | **POST** /v1/user_requests | Create a request on behalf of the user
*UsersApi* | [**delete_challenge_method**](agilicus_api/docs/UsersApi.md#delete_challenge_method) | **DELETE** /users/{user_id}/mfa_challenge_methods/{challenge_method_id} | Delete a user&#39;s multi-factor authentication challenge method
*UsersApi* | [**delete_service_account**](agilicus_api/docs/UsersApi.md#delete_service_account) | **DELETE** /v1/service_accounts/{service_account_id} | Delete a service account
*UsersApi* | [**delete_upstream_user_identity**](agilicus_api/docs/UsersApi.md#delete_upstream_user_identity) | **DELETE** /users/{user_id}/upstream_user_identities/{upstream_user_identity_id} | Delete an upstream user identity
*UsersApi* | [**delete_user**](agilicus_api/docs/UsersApi.md#delete_user) | **DELETE** /v1/orgs/{org_id}/users/{user_id} | Remove a user from an organisation
*UsersApi* | [**delete_user_metadata**](agilicus_api/docs/UsersApi.md#delete_user_metadata) | **DELETE** /v1/user_metadata/{metadata_id} | Delete an user metadata entry
*UsersApi* | [**delete_user_request**](agilicus_api/docs/UsersApi.md#delete_user_request) | **DELETE** /v1/user_requests/{user_request_id} | Delete an user request
*UsersApi* | [**get_challenge_method**](agilicus_api/docs/UsersApi.md#get_challenge_method) | **GET** /users/{user_id}/mfa_challenge_methods/{challenge_method_id} | Get a single challenge method for the given user
*UsersApi* | [**get_service_account**](agilicus_api/docs/UsersApi.md#get_service_account) | **GET** /v1/service_accounts/{service_account_id} | Get a service account
*UsersApi* | [**get_upstream_user_identity**](agilicus_api/docs/UsersApi.md#get_upstream_user_identity) | **GET** /users/{user_id}/upstream_user_identities/{upstream_user_identity_id} | Get a single upstream user identity
*UsersApi* | [**get_user**](agilicus_api/docs/UsersApi.md#get_user) | **GET** /users/{user_id} | Get a single user
*UsersApi* | [**get_user_metadata**](agilicus_api/docs/UsersApi.md#get_user_metadata) | **GET** /v1/user_metadata/{metadata_id} | Get a single user metadata entry
*UsersApi* | [**get_user_request**](agilicus_api/docs/UsersApi.md#get_user_request) | **GET** /v1/user_requests/{user_request_id} | Get a single user request
*UsersApi* | [**list_access_requests**](agilicus_api/docs/UsersApi.md#list_access_requests) | **GET** /v1/access_requests | Get a list of access requests
*UsersApi* | [**list_all_resource_permissions**](agilicus_api/docs/UsersApi.md#list_all_resource_permissions) | **GET** /users/{user_id}/render_resource_permissions | Return all per-resource permissions for a user
*UsersApi* | [**list_all_user_orgs**](agilicus_api/docs/UsersApi.md#list_all_user_orgs) | **GET** /users/{user_id}/orgs | Return all organisations a user has been assigned to
*UsersApi* | [**list_all_user_roles**](agilicus_api/docs/UsersApi.md#list_all_user_roles) | **GET** /users/{user_id}/render_roles | Return all roles for a user
*UsersApi* | [**list_challenge_methods**](agilicus_api/docs/UsersApi.md#list_challenge_methods) | **GET** /users/{user_id}/mfa_challenge_methods | Get all of a user&#39;s multi-factor authentication challenge method configuration
*UsersApi* | [**list_combined_user_details**](agilicus_api/docs/UsersApi.md#list_combined_user_details) | **GET** /v1/combined_user_details | Get all combined details about users
*UsersApi* | [**list_org_user_roles**](agilicus_api/docs/UsersApi.md#list_org_user_roles) | **GET** /users/org_user_roles | Get all org user roles
*UsersApi* | [**list_service_accounts**](agilicus_api/docs/UsersApi.md#list_service_accounts) | **GET** /v1/service_accounts | List service accounts
*UsersApi* | [**list_upstream_user_identities**](agilicus_api/docs/UsersApi.md#list_upstream_user_identities) | **GET** /users/{user_id}/upstream_user_identities | Get all of a user&#39;s upstream user identities
*UsersApi* | [**list_user_application_access_info**](agilicus_api/docs/UsersApi.md#list_user_application_access_info) | **GET** /v1/user_application_access_info | Query various users&#39; application access information
*UsersApi* | [**list_user_file_share_access_info**](agilicus_api/docs/UsersApi.md#list_user_file_share_access_info) | **GET** /v1/user_file_share_access_info | Query various users&#39; file share access information
*UsersApi* | [**list_user_guids**](agilicus_api/docs/UsersApi.md#list_user_guids) | **GET** /users_ids | Get a list of all user GUIDs
*UsersApi* | [**list_user_launcher_access_info**](agilicus_api/docs/UsersApi.md#list_user_launcher_access_info) | **GET** /v1/user_launcher_access_info | Query various users&#39; launchers access information
*UsersApi* | [**list_user_metadata**](agilicus_api/docs/UsersApi.md#list_user_metadata) | **GET** /v1/user_metadata | Get a list of user metadata entries
*UsersApi* | [**list_user_permissions**](agilicus_api/docs/UsersApi.md#list_user_permissions) | **GET** /users/{user_id}/host_permissions | Return the user&#39;s host permissions
*UsersApi* | [**list_user_requests**](agilicus_api/docs/UsersApi.md#list_user_requests) | **GET** /v1/user_requests | Get a list of user requests
*UsersApi* | [**list_user_resource_access_info**](agilicus_api/docs/UsersApi.md#list_user_resource_access_info) | **GET** /v1/user_resource_access_info | Query various users&#39; resource access information
*UsersApi* | [**list_users**](agilicus_api/docs/UsersApi.md#list_users) | **GET** /users | Get all users
*UsersApi* | [**replace_challenge_method**](agilicus_api/docs/UsersApi.md#replace_challenge_method) | **PUT** /users/{user_id}/mfa_challenge_methods/{challenge_method_id} | Update a user&#39;s multi-factor authentication challenge method
*UsersApi* | [**replace_service_account**](agilicus_api/docs/UsersApi.md#replace_service_account) | **PUT** /v1/service_accounts/{service_account_id} | Update a service account
*UsersApi* | [**replace_upstream_user_identity**](agilicus_api/docs/UsersApi.md#replace_upstream_user_identity) | **PUT** /users/{user_id}/upstream_user_identities/{upstream_user_identity_id} | Update an upstream user identity
*UsersApi* | [**replace_user**](agilicus_api/docs/UsersApi.md#replace_user) | **PUT** /users/{user_id} | Create or update a user
*UsersApi* | [**replace_user_metadata**](agilicus_api/docs/UsersApi.md#replace_user_metadata) | **PUT** /v1/user_metadata/{metadata_id} | Update an user metadata entry.
*UsersApi* | [**replace_user_request**](agilicus_api/docs/UsersApi.md#replace_user_request) | **PUT** /v1/user_requests/{user_request_id} | Update an user request. Note this method ignores the state parameter.
*UsersApi* | [**replace_user_role**](agilicus_api/docs/UsersApi.md#replace_user_role) | **PUT** /users/{user_id}/roles | Create or update a user role
*UsersApi* | [**reset_user_mfa_challenge_methods**](agilicus_api/docs/UsersApi.md#reset_user_mfa_challenge_methods) | **POST** /users/{user_id}/reset_mfa_challenge_methods | Resets a user&#39;s multi-factor authentication method
*UsersApi* | [**update_user_request**](agilicus_api/docs/UsersApi.md#update_user_request) | **POST** /v1/user_requests/{user_request_id} | Uses the state parameter in the body to apply the action to the request
*WhoamiApi* | [**create_whoami**](agilicus_api/docs/WhoamiApi.md#create_whoami) | **POST** /v1/whoami | login through whoami


## Documentation For Models

 - [APIKey](agilicus_api/docs/APIKey.md)
 - [APIKeyIntrospect](agilicus_api/docs/APIKeyIntrospect.md)
 - [APIKeyIntrospectAuthorizationInfo](agilicus_api/docs/APIKeyIntrospectAuthorizationInfo.md)
 - [APIKeyIntrospectResponse](agilicus_api/docs/APIKeyIntrospectResponse.md)
 - [APIKeyOpStatus](agilicus_api/docs/APIKeyOpStatus.md)
 - [APIKeySpec](agilicus_api/docs/APIKeySpec.md)
 - [APIKeyStatus](agilicus_api/docs/APIKeyStatus.md)
 - [AccessRequests](agilicus_api/docs/AccessRequests.md)
 - [AccessRequestsStatus](agilicus_api/docs/AccessRequestsStatus.md)
 - [AddGroupMemberRequest](agilicus_api/docs/AddGroupMemberRequest.md)
 - [AgentConnector](agilicus_api/docs/AgentConnector.md)
 - [AgentConnectorAuthzStats](agilicus_api/docs/AgentConnectorAuthzStats.md)
 - [AgentConnectorConnectionInfo](agilicus_api/docs/AgentConnectorConnectionInfo.md)
 - [AgentConnectorInfo](agilicus_api/docs/AgentConnectorInfo.md)
 - [AgentConnectorLocalBind](agilicus_api/docs/AgentConnectorLocalBind.md)
 - [AgentConnectorLocalBindError](agilicus_api/docs/AgentConnectorLocalBindError.md)
 - [AgentConnectorLocalBindStats](agilicus_api/docs/AgentConnectorLocalBindStats.md)
 - [AgentConnectorPerShareStats](agilicus_api/docs/AgentConnectorPerShareStats.md)
 - [AgentConnectorPerUserStats](agilicus_api/docs/AgentConnectorPerUserStats.md)
 - [AgentConnectorProxyRequestStats](agilicus_api/docs/AgentConnectorProxyRequestStats.md)
 - [AgentConnectorProxyRequestStatsDetails](agilicus_api/docs/AgentConnectorProxyRequestStatsDetails.md)
 - [AgentConnectorProxyStats](agilicus_api/docs/AgentConnectorProxyStats.md)
 - [AgentConnectorRouting](agilicus_api/docs/AgentConnectorRouting.md)
 - [AgentConnectorRoutingStats](agilicus_api/docs/AgentConnectorRoutingStats.md)
 - [AgentConnectorShareStats](agilicus_api/docs/AgentConnectorShareStats.md)
 - [AgentConnectorSpec](agilicus_api/docs/AgentConnectorSpec.md)
 - [AgentConnectorSpecProvisioning](agilicus_api/docs/AgentConnectorSpecProvisioning.md)
 - [AgentConnectorSpecificStats](agilicus_api/docs/AgentConnectorSpecificStats.md)
 - [AgentConnectorStats](agilicus_api/docs/AgentConnectorStats.md)
 - [AgentConnectorStatus](agilicus_api/docs/AgentConnectorStatus.md)
 - [AgentConnectorSystemStats](agilicus_api/docs/AgentConnectorSystemStats.md)
 - [AgentConnectorTransportStats](agilicus_api/docs/AgentConnectorTransportStats.md)
 - [AgentConnectorTunnelInfo](agilicus_api/docs/AgentConnectorTunnelInfo.md)
 - [AgentConnectorUserStats](agilicus_api/docs/AgentConnectorUserStats.md)
 - [AgentLocalAuthInfo](agilicus_api/docs/AgentLocalAuthInfo.md)
 - [AllowMapCompiled](agilicus_api/docs/AllowMapCompiled.md)
 - [AllowRuleCompiled](agilicus_api/docs/AllowRuleCompiled.md)
 - [Application](agilicus_api/docs/Application.md)
 - [ApplicationAdditionalContext](agilicus_api/docs/ApplicationAdditionalContext.md)
 - [ApplicationAssignment](agilicus_api/docs/ApplicationAssignment.md)
 - [ApplicationAuthenticationConfig](agilicus_api/docs/ApplicationAuthenticationConfig.md)
 - [ApplicationConfig](agilicus_api/docs/ApplicationConfig.md)
 - [ApplicationMonitoringConfig](agilicus_api/docs/ApplicationMonitoringConfig.md)
 - [ApplicationSecurity](agilicus_api/docs/ApplicationSecurity.md)
 - [ApplicationService](agilicus_api/docs/ApplicationService.md)
 - [ApplicationServiceAssignment](agilicus_api/docs/ApplicationServiceAssignment.md)
 - [ApplicationServiceStats](agilicus_api/docs/ApplicationServiceStats.md)
 - [ApplicationServiceStatsGroup](agilicus_api/docs/ApplicationServiceStatsGroup.md)
 - [ApplicationStateSelector](agilicus_api/docs/ApplicationStateSelector.md)
 - [ApplicationSummary](agilicus_api/docs/ApplicationSummary.md)
 - [ApplicationSummaryStatus](agilicus_api/docs/ApplicationSummaryStatus.md)
 - [ApplicationUpstreamConfig](agilicus_api/docs/ApplicationUpstreamConfig.md)
 - [ApplicationUpstreamFormInfo](agilicus_api/docs/ApplicationUpstreamFormInfo.md)
 - [ApplicationUpstreamIdentityProvider](agilicus_api/docs/ApplicationUpstreamIdentityProvider.md)
 - [ApplicationUpstreamValidation](agilicus_api/docs/ApplicationUpstreamValidation.md)
 - [Audit](agilicus_api/docs/Audit.md)
 - [AuditDestination](agilicus_api/docs/AuditDestination.md)
 - [AuditDestinationAuthentication](agilicus_api/docs/AuditDestinationAuthentication.md)
 - [AuditDestinationFilter](agilicus_api/docs/AuditDestinationFilter.md)
 - [AuditDestinationSpec](agilicus_api/docs/AuditDestinationSpec.md)
 - [AuditEvent](agilicus_api/docs/AuditEvent.md)
 - [AuditEventResponse](agilicus_api/docs/AuditEventResponse.md)
 - [AuditWebhookBulkEvent](agilicus_api/docs/AuditWebhookBulkEvent.md)
 - [AuditWebhookEventsProcessed](agilicus_api/docs/AuditWebhookEventsProcessed.md)
 - [AuthAudits](agilicus_api/docs/AuthAudits.md)
 - [AuthenticationAttribute](agilicus_api/docs/AuthenticationAttribute.md)
 - [AuthenticationDocument](agilicus_api/docs/AuthenticationDocument.md)
 - [AuthenticationDocumentSpec](agilicus_api/docs/AuthenticationDocumentSpec.md)
 - [AuthenticationDocumentStatus](agilicus_api/docs/AuthenticationDocumentStatus.md)
 - [AutoCreateStatus](agilicus_api/docs/AutoCreateStatus.md)
 - [BaseUpstream](agilicus_api/docs/BaseUpstream.md)
 - [BaseUpstreams](agilicus_api/docs/BaseUpstreams.md)
 - [BillingAccount](agilicus_api/docs/BillingAccount.md)
 - [BillingAccountSpec](agilicus_api/docs/BillingAccountSpec.md)
 - [BillingAccountStatus](agilicus_api/docs/BillingAccountStatus.md)
 - [BillingCustomer](agilicus_api/docs/BillingCustomer.md)
 - [BillingOrg](agilicus_api/docs/BillingOrg.md)
 - [BillingPortalLink](agilicus_api/docs/BillingPortalLink.md)
 - [BillingProduct](agilicus_api/docs/BillingProduct.md)
 - [BillingProductPrice](agilicus_api/docs/BillingProductPrice.md)
 - [BillingSubscription](agilicus_api/docs/BillingSubscription.md)
 - [BillingUsageRecord](agilicus_api/docs/BillingUsageRecord.md)
 - [BillingUsageSummary](agilicus_api/docs/BillingUsageSummary.md)
 - [BulkSessionOperationResponse](agilicus_api/docs/BulkSessionOperationResponse.md)
 - [BulkTokenRevoke](agilicus_api/docs/BulkTokenRevoke.md)
 - [BulkTokenRevokeResponse](agilicus_api/docs/BulkTokenRevokeResponse.md)
 - [BulkUserMetadata](agilicus_api/docs/BulkUserMetadata.md)
 - [CORSOrigin](agilicus_api/docs/CORSOrigin.md)
 - [CORSSettings](agilicus_api/docs/CORSSettings.md)
 - [CSPDirective](agilicus_api/docs/CSPDirective.md)
 - [CSPSettings](agilicus_api/docs/CSPSettings.md)
 - [CSRReasonEnum](agilicus_api/docs/CSRReasonEnum.md)
 - [Catalogue](agilicus_api/docs/Catalogue.md)
 - [CatalogueEntry](agilicus_api/docs/CatalogueEntry.md)
 - [CertSigningReq](agilicus_api/docs/CertSigningReq.md)
 - [CertSigningReqSpec](agilicus_api/docs/CertSigningReqSpec.md)
 - [CertSigningReqStatus](agilicus_api/docs/CertSigningReqStatus.md)
 - [CertificateTransparencySettings](agilicus_api/docs/CertificateTransparencySettings.md)
 - [Challenge](agilicus_api/docs/Challenge.md)
 - [ChallengeAnswer](agilicus_api/docs/ChallengeAnswer.md)
 - [ChallengeAnswerSpec](agilicus_api/docs/ChallengeAnswerSpec.md)
 - [ChallengeEndpoint](agilicus_api/docs/ChallengeEndpoint.md)
 - [ChallengeSpec](agilicus_api/docs/ChallengeSpec.md)
 - [ChallengeStatus](agilicus_api/docs/ChallengeStatus.md)
 - [CipherDiffieHellmanGroup](agilicus_api/docs/CipherDiffieHellmanGroup.md)
 - [CipherEncryptionAlgorithm](agilicus_api/docs/CipherEncryptionAlgorithm.md)
 - [CipherIntegrityAlgorithm](agilicus_api/docs/CipherIntegrityAlgorithm.md)
 - [CombinedRules](agilicus_api/docs/CombinedRules.md)
 - [CombinedRulesStatus](agilicus_api/docs/CombinedRulesStatus.md)
 - [CombinedUserDetail](agilicus_api/docs/CombinedUserDetail.md)
 - [CombinedUserDetailStatus](agilicus_api/docs/CombinedUserDetailStatus.md)
 - [CommonMetadata](agilicus_api/docs/CommonMetadata.md)
 - [Connector](agilicus_api/docs/Connector.md)
 - [ConnectorDiagnosticStats](agilicus_api/docs/ConnectorDiagnosticStats.md)
 - [ConnectorSpec](agilicus_api/docs/ConnectorSpec.md)
 - [ConnectorStats](agilicus_api/docs/ConnectorStats.md)
 - [ConnectorStatsMetadata](agilicus_api/docs/ConnectorStatsMetadata.md)
 - [ConnectorStatus](agilicus_api/docs/ConnectorStatus.md)
 - [ConnectorSystemStats](agilicus_api/docs/ConnectorSystemStats.md)
 - [ContentTypeOptionsSettings](agilicus_api/docs/ContentTypeOptionsSettings.md)
 - [CreateBillingUsageRecords](agilicus_api/docs/CreateBillingUsageRecords.md)
 - [CreateSessionAndTokenRequest](agilicus_api/docs/CreateSessionAndTokenRequest.md)
 - [CreateSessionAndTokenResponse](agilicus_api/docs/CreateSessionAndTokenResponse.md)
 - [CreateTokenRequest](agilicus_api/docs/CreateTokenRequest.md)
 - [CrossOriginEmbedderPolicySettings](agilicus_api/docs/CrossOriginEmbedderPolicySettings.md)
 - [CrossOriginOpenerPolicySettings](agilicus_api/docs/CrossOriginOpenerPolicySettings.md)
 - [CrossOriginResourcePolicySettings](agilicus_api/docs/CrossOriginResourcePolicySettings.md)
 - [Definition](agilicus_api/docs/Definition.md)
 - [DesktopClientConfiguration](agilicus_api/docs/DesktopClientConfiguration.md)
 - [DesktopClientGeneratedConfiguration](agilicus_api/docs/DesktopClientGeneratedConfiguration.md)
 - [DesktopResource](agilicus_api/docs/DesktopResource.md)
 - [DesktopResourceSpec](agilicus_api/docs/DesktopResourceSpec.md)
 - [DesktopResourceStats](agilicus_api/docs/DesktopResourceStats.md)
 - [DesktopResourceStatus](agilicus_api/docs/DesktopResourceStatus.md)
 - [Domain](agilicus_api/docs/Domain.md)
 - [Email](agilicus_api/docs/Email.md)
 - [Environment](agilicus_api/docs/Environment.md)
 - [EnvironmentConfig](agilicus_api/docs/EnvironmentConfig.md)
 - [EnvironmentConfigVar](agilicus_api/docs/EnvironmentConfigVar.md)
 - [EnvironmentStatus](agilicus_api/docs/EnvironmentStatus.md)
 - [ErrorMessage](agilicus_api/docs/ErrorMessage.md)
 - [FeatureFlag](agilicus_api/docs/FeatureFlag.md)
 - [File](agilicus_api/docs/File.md)
 - [FileName](agilicus_api/docs/FileName.md)
 - [FileShareClientConfig](agilicus_api/docs/FileShareClientConfig.md)
 - [FileShareClientConfigLinuxConfig](agilicus_api/docs/FileShareClientConfigLinuxConfig.md)
 - [FileShareClientConfigWindowsConfig](agilicus_api/docs/FileShareClientConfigWindowsConfig.md)
 - [FileShareService](agilicus_api/docs/FileShareService.md)
 - [FileShareServiceSpec](agilicus_api/docs/FileShareServiceSpec.md)
 - [FileShareServiceStats](agilicus_api/docs/FileShareServiceStats.md)
 - [FileShareServiceStatsGroup](agilicus_api/docs/FileShareServiceStatsGroup.md)
 - [FileShareServiceStatus](agilicus_api/docs/FileShareServiceStatus.md)
 - [FileSummary](agilicus_api/docs/FileSummary.md)
 - [FileVisibility](agilicus_api/docs/FileVisibility.md)
 - [FrameOptionsSettings](agilicus_api/docs/FrameOptionsSettings.md)
 - [GenericFloatMetric](agilicus_api/docs/GenericFloatMetric.md)
 - [GenericIntMetric](agilicus_api/docs/GenericIntMetric.md)
 - [Group](agilicus_api/docs/Group.md)
 - [GroupData](agilicus_api/docs/GroupData.md)
 - [GroupMember](agilicus_api/docs/GroupMember.md)
 - [GroupReconcileRecord](agilicus_api/docs/GroupReconcileRecord.md)
 - [HSTSSettings](agilicus_api/docs/HSTSSettings.md)
 - [HTTPBasicAuth](agilicus_api/docs/HTTPBasicAuth.md)
 - [HTTPBearerAuth](agilicus_api/docs/HTTPBearerAuth.md)
 - [HTTPSecuritySettings](agilicus_api/docs/HTTPSecuritySettings.md)
 - [HostPermissions](agilicus_api/docs/HostPermissions.md)
 - [HttpRequestExtractor](agilicus_api/docs/HttpRequestExtractor.md)
 - [HttpRequestExtractorSource](agilicus_api/docs/HttpRequestExtractorSource.md)
 - [HttpRule](agilicus_api/docs/HttpRule.md)
 - [IdentityAssertion](agilicus_api/docs/IdentityAssertion.md)
 - [IdentityAssertionResponse](agilicus_api/docs/IdentityAssertionResponse.md)
 - [IncludedRole](agilicus_api/docs/IncludedRole.md)
 - [InterceptorCommand](agilicus_api/docs/InterceptorCommand.md)
 - [InterceptorConfig](agilicus_api/docs/InterceptorConfig.md)
 - [IpsecConnection](agilicus_api/docs/IpsecConnection.md)
 - [IpsecConnectionIpv4Block](agilicus_api/docs/IpsecConnectionIpv4Block.md)
 - [IpsecConnectionSpec](agilicus_api/docs/IpsecConnectionSpec.md)
 - [IpsecConnector](agilicus_api/docs/IpsecConnector.md)
 - [IpsecConnectorSpec](agilicus_api/docs/IpsecConnectorSpec.md)
 - [IpsecConnectorStatus](agilicus_api/docs/IpsecConnectorStatus.md)
 - [IpsecGatewayInterface](agilicus_api/docs/IpsecGatewayInterface.md)
 - [Issuer](agilicus_api/docs/Issuer.md)
 - [IssuerClient](agilicus_api/docs/IssuerClient.md)
 - [IssuerUpstream](agilicus_api/docs/IssuerUpstream.md)
 - [JSONBodyConstraint](agilicus_api/docs/JSONBodyConstraint.md)
 - [K8sSlug](agilicus_api/docs/K8sSlug.md)
 - [KerberosUpstreamConfig](agilicus_api/docs/KerberosUpstreamConfig.md)
 - [KerberosUpstreamIdentityProvider](agilicus_api/docs/KerberosUpstreamIdentityProvider.md)
 - [KerberosUpstreamStatus](agilicus_api/docs/KerberosUpstreamStatus.md)
 - [KerberosUpstreamStatusKeyTabEntries](agilicus_api/docs/KerberosUpstreamStatusKeyTabEntries.md)
 - [Launcher](agilicus_api/docs/Launcher.md)
 - [LauncherConfig](agilicus_api/docs/LauncherConfig.md)
 - [LauncherSpec](agilicus_api/docs/LauncherSpec.md)
 - [LauncherStatus](agilicus_api/docs/LauncherStatus.md)
 - [ListAPIKeysResponse](agilicus_api/docs/ListAPIKeysResponse.md)
 - [ListAccessRequestsResponse](agilicus_api/docs/ListAccessRequestsResponse.md)
 - [ListActiveUsersResponse](agilicus_api/docs/ListActiveUsersResponse.md)
 - [ListAgentConnectorResponse](agilicus_api/docs/ListAgentConnectorResponse.md)
 - [ListApplicationServicesResponse](agilicus_api/docs/ListApplicationServicesResponse.md)
 - [ListApplicationSummaryResponse](agilicus_api/docs/ListApplicationSummaryResponse.md)
 - [ListApplicationsResponse](agilicus_api/docs/ListApplicationsResponse.md)
 - [ListAuditDestinationsResponse](agilicus_api/docs/ListAuditDestinationsResponse.md)
 - [ListAuditsResponse](agilicus_api/docs/ListAuditsResponse.md)
 - [ListAuthAuditsResponse](agilicus_api/docs/ListAuthAuditsResponse.md)
 - [ListAuthenticationDocumentResponse](agilicus_api/docs/ListAuthenticationDocumentResponse.md)
 - [ListBillingAccountsResponse](agilicus_api/docs/ListBillingAccountsResponse.md)
 - [ListBillingUsageRecordsResponse](agilicus_api/docs/ListBillingUsageRecordsResponse.md)
 - [ListCatalogueEntriesResponse](agilicus_api/docs/ListCatalogueEntriesResponse.md)
 - [ListCataloguesResponse](agilicus_api/docs/ListCataloguesResponse.md)
 - [ListCertSigningReqResponse](agilicus_api/docs/ListCertSigningReqResponse.md)
 - [ListCombinedRulesResponse](agilicus_api/docs/ListCombinedRulesResponse.md)
 - [ListCombinedUserDetailsResponse](agilicus_api/docs/ListCombinedUserDetailsResponse.md)
 - [ListConfigsResponse](agilicus_api/docs/ListConfigsResponse.md)
 - [ListConnectorResponse](agilicus_api/docs/ListConnectorResponse.md)
 - [ListDesktopResourcesResponse](agilicus_api/docs/ListDesktopResourcesResponse.md)
 - [ListDomainsResponse](agilicus_api/docs/ListDomainsResponse.md)
 - [ListElevatedUserRoles](agilicus_api/docs/ListElevatedUserRoles.md)
 - [ListEnvironmentConfigsResponse](agilicus_api/docs/ListEnvironmentConfigsResponse.md)
 - [ListFileShareServicesResponse](agilicus_api/docs/ListFileShareServicesResponse.md)
 - [ListFilesResponse](agilicus_api/docs/ListFilesResponse.md)
 - [ListGroupsResponse](agilicus_api/docs/ListGroupsResponse.md)
 - [ListIpsecConnectorResponse](agilicus_api/docs/ListIpsecConnectorResponse.md)
 - [ListIssuerClientsResponse](agilicus_api/docs/ListIssuerClientsResponse.md)
 - [ListIssuerExtensionsResponse](agilicus_api/docs/ListIssuerExtensionsResponse.md)
 - [ListIssuerRootsResponse](agilicus_api/docs/ListIssuerRootsResponse.md)
 - [ListIssuerUpstreams](agilicus_api/docs/ListIssuerUpstreams.md)
 - [ListLaunchersResponse](agilicus_api/docs/ListLaunchersResponse.md)
 - [ListLogsResponse](agilicus_api/docs/ListLogsResponse.md)
 - [ListMFAChallengeMethods](agilicus_api/docs/ListMFAChallengeMethods.md)
 - [ListMessageEndpointsResponse](agilicus_api/docs/ListMessageEndpointsResponse.md)
 - [ListOrgsResponse](agilicus_api/docs/ListOrgsResponse.md)
 - [ListPoliciesResponse](agilicus_api/docs/ListPoliciesResponse.md)
 - [ListPolicyRulesResponse](agilicus_api/docs/ListPolicyRulesResponse.md)
 - [ListProductsResponse](agilicus_api/docs/ListProductsResponse.md)
 - [ListResourcePermissionsResponse](agilicus_api/docs/ListResourcePermissionsResponse.md)
 - [ListResourceRolesResponse](agilicus_api/docs/ListResourceRolesResponse.md)
 - [ListResourcesResponse](agilicus_api/docs/ListResourcesResponse.md)
 - [ListRoleToRuleEntries](agilicus_api/docs/ListRoleToRuleEntries.md)
 - [ListRoles](agilicus_api/docs/ListRoles.md)
 - [ListRules](agilicus_api/docs/ListRules.md)
 - [ListSecureAgentResponse](agilicus_api/docs/ListSecureAgentResponse.md)
 - [ListServiceAccountResponse](agilicus_api/docs/ListServiceAccountResponse.md)
 - [ListServiceForwardersResponse](agilicus_api/docs/ListServiceForwardersResponse.md)
 - [ListSessionsResponse](agilicus_api/docs/ListSessionsResponse.md)
 - [ListTOTPEnrollmentResponse](agilicus_api/docs/ListTOTPEnrollmentResponse.md)
 - [ListTokensResponse](agilicus_api/docs/ListTokensResponse.md)
 - [ListTopUsersResponse](agilicus_api/docs/ListTopUsersResponse.md)
 - [ListUpstreamAliases](agilicus_api/docs/ListUpstreamAliases.md)
 - [ListUpstreamGroupMapping](agilicus_api/docs/ListUpstreamGroupMapping.md)
 - [ListUpstreamUserIdentitiesResponse](agilicus_api/docs/ListUpstreamUserIdentitiesResponse.md)
 - [ListUserApplicationAccessInfoResponse](agilicus_api/docs/ListUserApplicationAccessInfoResponse.md)
 - [ListUserFileShareAccessInfoResponse](agilicus_api/docs/ListUserFileShareAccessInfoResponse.md)
 - [ListUserGuidsResponse](agilicus_api/docs/ListUserGuidsResponse.md)
 - [ListUserLauncherAccessInfoResponse](agilicus_api/docs/ListUserLauncherAccessInfoResponse.md)
 - [ListUserMetadataResponse](agilicus_api/docs/ListUserMetadataResponse.md)
 - [ListUserRequestInfoResponse](agilicus_api/docs/ListUserRequestInfoResponse.md)
 - [ListUserResourceAccessInfoResponse](agilicus_api/docs/ListUserResourceAccessInfoResponse.md)
 - [ListUserRolesForAnOrg](agilicus_api/docs/ListUserRolesForAnOrg.md)
 - [ListUsersResponse](agilicus_api/docs/ListUsersResponse.md)
 - [ListWebAuthNEnrollmentResponse](agilicus_api/docs/ListWebAuthNEnrollmentResponse.md)
 - [ListWellKnownIssuerInfo](agilicus_api/docs/ListWellKnownIssuerInfo.md)
 - [ListX509CertificateResponse](agilicus_api/docs/ListX509CertificateResponse.md)
 - [LocalAuthUpstreamConfig](agilicus_api/docs/LocalAuthUpstreamConfig.md)
 - [LocalAuthUpstreamIdentityProvider](agilicus_api/docs/LocalAuthUpstreamIdentityProvider.md)
 - [Log](agilicus_api/docs/Log.md)
 - [LoginSession](agilicus_api/docs/LoginSession.md)
 - [MFAChallengeAnswer](agilicus_api/docs/MFAChallengeAnswer.md)
 - [MFAChallengeAnswerResult](agilicus_api/docs/MFAChallengeAnswerResult.md)
 - [MFAChallengeMethod](agilicus_api/docs/MFAChallengeMethod.md)
 - [MFAChallengeMethodSpec](agilicus_api/docs/MFAChallengeMethodSpec.md)
 - [MFAChallengeQuestion](agilicus_api/docs/MFAChallengeQuestion.md)
 - [MFAChallengeQuestionInput](agilicus_api/docs/MFAChallengeQuestionInput.md)
 - [MFAChallengeQuestionLoginInfo](agilicus_api/docs/MFAChallengeQuestionLoginInfo.md)
 - [MFAEnrollmentAnswer](agilicus_api/docs/MFAEnrollmentAnswer.md)
 - [MFAEnrollmentAnswerResult](agilicus_api/docs/MFAEnrollmentAnswerResult.md)
 - [MFAEnrollmentQuestion](agilicus_api/docs/MFAEnrollmentQuestion.md)
 - [MFAEnrollmentQuestionInput](agilicus_api/docs/MFAEnrollmentQuestionInput.md)
 - [MFAEnrollmentQuestionLoginInfo](agilicus_api/docs/MFAEnrollmentQuestionLoginInfo.md)
 - [ManagedUpstreamIdentityProvider](agilicus_api/docs/ManagedUpstreamIdentityProvider.md)
 - [ManyOrgTokenIntrospectResponse](agilicus_api/docs/ManyOrgTokenIntrospectResponse.md)
 - [MapAttributesAnswer](agilicus_api/docs/MapAttributesAnswer.md)
 - [MapAttributesAnswerResult](agilicus_api/docs/MapAttributesAnswerResult.md)
 - [MapAttributesQuestion](agilicus_api/docs/MapAttributesQuestion.md)
 - [MapAttributesQuestionInput](agilicus_api/docs/MapAttributesQuestionInput.md)
 - [MapAttributesQuestionLoginInfo](agilicus_api/docs/MapAttributesQuestionLoginInfo.md)
 - [MappedAttributes](agilicus_api/docs/MappedAttributes.md)
 - [Message](agilicus_api/docs/Message.md)
 - [MessageAction](agilicus_api/docs/MessageAction.md)
 - [MessageEndpoint](agilicus_api/docs/MessageEndpoint.md)
 - [MessageEndpointMetadata](agilicus_api/docs/MessageEndpointMetadata.md)
 - [MessageEndpointSpec](agilicus_api/docs/MessageEndpointSpec.md)
 - [MessageEndpointType](agilicus_api/docs/MessageEndpointType.md)
 - [MessageEndpointTypeWebPush](agilicus_api/docs/MessageEndpointTypeWebPush.md)
 - [MessageEndpointsConfig](agilicus_api/docs/MessageEndpointsConfig.md)
 - [MetadataWithId](agilicus_api/docs/MetadataWithId.md)
 - [MetadataWithIdAllOf](agilicus_api/docs/MetadataWithIdAllOf.md)
 - [MetadataWithOnlyId](agilicus_api/docs/MetadataWithOnlyId.md)
 - [NetworkMountRuleConfig](agilicus_api/docs/NetworkMountRuleConfig.md)
 - [NetworkPort](agilicus_api/docs/NetworkPort.md)
 - [NetworkPortRange](agilicus_api/docs/NetworkPortRange.md)
 - [NetworkServiceConfig](agilicus_api/docs/NetworkServiceConfig.md)
 - [NextPageEmail](agilicus_api/docs/NextPageEmail.md)
 - [OIDCAuthConfig](agilicus_api/docs/OIDCAuthConfig.md)
 - [OIDCAuthPathConfig](agilicus_api/docs/OIDCAuthPathConfig.md)
 - [OIDCAuthURI](agilicus_api/docs/OIDCAuthURI.md)
 - [OIDCContentType](agilicus_api/docs/OIDCContentType.md)
 - [OIDCProxyConfig](agilicus_api/docs/OIDCProxyConfig.md)
 - [OIDCProxyContentManipulation](agilicus_api/docs/OIDCProxyContentManipulation.md)
 - [OIDCProxyDomainMapping](agilicus_api/docs/OIDCProxyDomainMapping.md)
 - [OIDCProxyDomainNameMapping](agilicus_api/docs/OIDCProxyDomainNameMapping.md)
 - [OIDCProxyDomainSubstitution](agilicus_api/docs/OIDCProxyDomainSubstitution.md)
 - [OIDCProxyHeader](agilicus_api/docs/OIDCProxyHeader.md)
 - [OIDCProxyHeaderMapping](agilicus_api/docs/OIDCProxyHeaderMapping.md)
 - [OIDCProxyHeaderMatch](agilicus_api/docs/OIDCProxyHeaderMatch.md)
 - [OIDCProxyHeaderName](agilicus_api/docs/OIDCProxyHeaderName.md)
 - [OIDCProxyHeaderOverride](agilicus_api/docs/OIDCProxyHeaderOverride.md)
 - [OIDCProxyHeaderRewriteFilter](agilicus_api/docs/OIDCProxyHeaderRewriteFilter.md)
 - [OIDCProxyHeaderUserConfig](agilicus_api/docs/OIDCProxyHeaderUserConfig.md)
 - [OIDCProxyScope](agilicus_api/docs/OIDCProxyScope.md)
 - [OIDCProxyStandardHeader](agilicus_api/docs/OIDCProxyStandardHeader.md)
 - [OIDCProxyUpstreamConfig](agilicus_api/docs/OIDCProxyUpstreamConfig.md)
 - [OIDCUpstreamIdentityProvider](agilicus_api/docs/OIDCUpstreamIdentityProvider.md)
 - [OrgInfo](agilicus_api/docs/OrgInfo.md)
 - [OrgScopePatchDocument](agilicus_api/docs/OrgScopePatchDocument.md)
 - [Organisation](agilicus_api/docs/Organisation.md)
 - [OrganisationAdmin](agilicus_api/docs/OrganisationAdmin.md)
 - [OrganisationStateSelector](agilicus_api/docs/OrganisationStateSelector.md)
 - [OrganisationStateStatus](agilicus_api/docs/OrganisationStateStatus.md)
 - [OrganisationStatus](agilicus_api/docs/OrganisationStatus.md)
 - [PermittedCrossDomainPoliciesSettings](agilicus_api/docs/PermittedCrossDomainPoliciesSettings.md)
 - [Policy](agilicus_api/docs/Policy.md)
 - [PolicyCondition](agilicus_api/docs/PolicyCondition.md)
 - [PolicyGroup](agilicus_api/docs/PolicyGroup.md)
 - [PolicyGroupSpec](agilicus_api/docs/PolicyGroupSpec.md)
 - [PolicyRule](agilicus_api/docs/PolicyRule.md)
 - [PolicyRuleSpec](agilicus_api/docs/PolicyRuleSpec.md)
 - [PolicySpec](agilicus_api/docs/PolicySpec.md)
 - [PreviousPageEmail](agilicus_api/docs/PreviousPageEmail.md)
 - [Product](agilicus_api/docs/Product.md)
 - [ProductSpec](agilicus_api/docs/ProductSpec.md)
 - [ProductStatus](agilicus_api/docs/ProductStatus.md)
 - [RawToken](agilicus_api/docs/RawToken.md)
 - [ReferrerPolicySettings](agilicus_api/docs/ReferrerPolicySettings.md)
 - [RenderedQueryParameter](agilicus_api/docs/RenderedQueryParameter.md)
 - [RenderedResourcePermissions](agilicus_api/docs/RenderedResourcePermissions.md)
 - [RenderedRule](agilicus_api/docs/RenderedRule.md)
 - [RenderedRuleBody](agilicus_api/docs/RenderedRuleBody.md)
 - [ReplaceUserRoleRequest](agilicus_api/docs/ReplaceUserRoleRequest.md)
 - [ResetMFAChallengeMethod](agilicus_api/docs/ResetMFAChallengeMethod.md)
 - [ResetPolicyRequest](agilicus_api/docs/ResetPolicyRequest.md)
 - [Resource](agilicus_api/docs/Resource.md)
 - [ResourceConfig](agilicus_api/docs/ResourceConfig.md)
 - [ResourceInfo](agilicus_api/docs/ResourceInfo.md)
 - [ResourceMember](agilicus_api/docs/ResourceMember.md)
 - [ResourcePermission](agilicus_api/docs/ResourcePermission.md)
 - [ResourcePermissionSpec](agilicus_api/docs/ResourcePermissionSpec.md)
 - [ResourceRole](agilicus_api/docs/ResourceRole.md)
 - [ResourceRoleSpec](agilicus_api/docs/ResourceRoleSpec.md)
 - [ResourceRuleGroup](agilicus_api/docs/ResourceRuleGroup.md)
 - [ResourceSessionStats](agilicus_api/docs/ResourceSessionStats.md)
 - [ResourceSpec](agilicus_api/docs/ResourceSpec.md)
 - [ResourceStats](agilicus_api/docs/ResourceStats.md)
 - [ResourceStatsMetadata](agilicus_api/docs/ResourceStatsMetadata.md)
 - [ResourceStatus](agilicus_api/docs/ResourceStatus.md)
 - [Role](agilicus_api/docs/Role.md)
 - [RoleConfig](agilicus_api/docs/RoleConfig.md)
 - [RoleList](agilicus_api/docs/RoleList.md)
 - [RoleSpec](agilicus_api/docs/RoleSpec.md)
 - [RoleToRuleEntry](agilicus_api/docs/RoleToRuleEntry.md)
 - [RoleToRuleEntrySpec](agilicus_api/docs/RoleToRuleEntrySpec.md)
 - [RoleV2](agilicus_api/docs/RoleV2.md)
 - [Roles](agilicus_api/docs/Roles.md)
 - [RolesConfig](agilicus_api/docs/RolesConfig.md)
 - [Rule](agilicus_api/docs/Rule.md)
 - [RuleConfig](agilicus_api/docs/RuleConfig.md)
 - [RuleMatchCriteria](agilicus_api/docs/RuleMatchCriteria.md)
 - [RuleMatcher](agilicus_api/docs/RuleMatcher.md)
 - [RuleMatcherList](agilicus_api/docs/RuleMatcherList.md)
 - [RuleQueryBody](agilicus_api/docs/RuleQueryBody.md)
 - [RuleQueryBodyJSON](agilicus_api/docs/RuleQueryBodyJSON.md)
 - [RuleQueryParameter](agilicus_api/docs/RuleQueryParameter.md)
 - [RuleScopeEnum](agilicus_api/docs/RuleScopeEnum.md)
 - [RuleSpec](agilicus_api/docs/RuleSpec.md)
 - [RuleV2](agilicus_api/docs/RuleV2.md)
 - [RulesConfig](agilicus_api/docs/RulesConfig.md)
 - [RuntimeStatus](agilicus_api/docs/RuntimeStatus.md)
 - [SecureAgent](agilicus_api/docs/SecureAgent.md)
 - [SecureAgentConnector](agilicus_api/docs/SecureAgentConnector.md)
 - [SecureAgentConnectorInfo](agilicus_api/docs/SecureAgentConnectorInfo.md)
 - [SecureAgentSpec](agilicus_api/docs/SecureAgentSpec.md)
 - [SecureAgentStatus](agilicus_api/docs/SecureAgentStatus.md)
 - [SelectorTag](agilicus_api/docs/SelectorTag.md)
 - [ServiceAccount](agilicus_api/docs/ServiceAccount.md)
 - [ServiceAccountResetBody](agilicus_api/docs/ServiceAccountResetBody.md)
 - [ServiceAccountSpec](agilicus_api/docs/ServiceAccountSpec.md)
 - [ServiceAccountStatus](agilicus_api/docs/ServiceAccountStatus.md)
 - [ServiceForwarder](agilicus_api/docs/ServiceForwarder.md)
 - [ServiceForwarderSpec](agilicus_api/docs/ServiceForwarderSpec.md)
 - [ServiceForwarderStats](agilicus_api/docs/ServiceForwarderStats.md)
 - [ServiceForwarderStatsGroup](agilicus_api/docs/ServiceForwarderStatsGroup.md)
 - [ServiceForwarderStatus](agilicus_api/docs/ServiceForwarderStatus.md)
 - [Session](agilicus_api/docs/Session.md)
 - [SessionsSpec](agilicus_api/docs/SessionsSpec.md)
 - [StorageRegion](agilicus_api/docs/StorageRegion.md)
 - [TOTPEnrollment](agilicus_api/docs/TOTPEnrollment.md)
 - [TOTPEnrollmentAnswer](agilicus_api/docs/TOTPEnrollmentAnswer.md)
 - [TOTPEnrollmentSpec](agilicus_api/docs/TOTPEnrollmentSpec.md)
 - [TOTPEnrollmentStatus](agilicus_api/docs/TOTPEnrollmentStatus.md)
 - [TemplateExtraction](agilicus_api/docs/TemplateExtraction.md)
 - [TemplatePath](agilicus_api/docs/TemplatePath.md)
 - [TimeIntervalMetrics](agilicus_api/docs/TimeIntervalMetrics.md)
 - [TimeValidity](agilicus_api/docs/TimeValidity.md)
 - [Token](agilicus_api/docs/Token.md)
 - [TokenIntrospect](agilicus_api/docs/TokenIntrospect.md)
 - [TokenIntrospectOptions](agilicus_api/docs/TokenIntrospectOptions.md)
 - [TokenReissueRequest](agilicus_api/docs/TokenReissueRequest.md)
 - [TokenRevoke](agilicus_api/docs/TokenRevoke.md)
 - [TokenScope](agilicus_api/docs/TokenScope.md)
 - [TokenValidity](agilicus_api/docs/TokenValidity.md)
 - [URIParameterRewriteFilter](agilicus_api/docs/URIParameterRewriteFilter.md)
 - [UpstreamAlias](agilicus_api/docs/UpstreamAlias.md)
 - [UpstreamAliasMapping](agilicus_api/docs/UpstreamAliasMapping.md)
 - [UpstreamAliasSpec](agilicus_api/docs/UpstreamAliasSpec.md)
 - [UpstreamGroupExcludedEntry](agilicus_api/docs/UpstreamGroupExcludedEntry.md)
 - [UpstreamGroupMapping](agilicus_api/docs/UpstreamGroupMapping.md)
 - [UpstreamGroupMappingEntry](agilicus_api/docs/UpstreamGroupMappingEntry.md)
 - [UpstreamGroupMappingSpec](agilicus_api/docs/UpstreamGroupMappingSpec.md)
 - [UpstreamGroupReconcile](agilicus_api/docs/UpstreamGroupReconcile.md)
 - [UpstreamGroupReconcileResponse](agilicus_api/docs/UpstreamGroupReconcileResponse.md)
 - [UpstreamUserIdentity](agilicus_api/docs/UpstreamUserIdentity.md)
 - [UpstreamUserIdentitySpec](agilicus_api/docs/UpstreamUserIdentitySpec.md)
 - [UsageMeasurement](agilicus_api/docs/UsageMeasurement.md)
 - [UsageMetric](agilicus_api/docs/UsageMetric.md)
 - [UsageMetrics](agilicus_api/docs/UsageMetrics.md)
 - [User](agilicus_api/docs/User.md)
 - [UserApplicationAccessInfo](agilicus_api/docs/UserApplicationAccessInfo.md)
 - [UserApplicationAccessInfoStatus](agilicus_api/docs/UserApplicationAccessInfoStatus.md)
 - [UserAttribute](agilicus_api/docs/UserAttribute.md)
 - [UserAttributes](agilicus_api/docs/UserAttributes.md)
 - [UserFileShareAccessInfo](agilicus_api/docs/UserFileShareAccessInfo.md)
 - [UserFileShareAccessInfoStatus](agilicus_api/docs/UserFileShareAccessInfoStatus.md)
 - [UserIdentity](agilicus_api/docs/UserIdentity.md)
 - [UserIdentityUpdate](agilicus_api/docs/UserIdentityUpdate.md)
 - [UserIdentityUpdateSpec](agilicus_api/docs/UserIdentityUpdateSpec.md)
 - [UserInfo](agilicus_api/docs/UserInfo.md)
 - [UserLauncherAccessInfo](agilicus_api/docs/UserLauncherAccessInfo.md)
 - [UserMemberOf](agilicus_api/docs/UserMemberOf.md)
 - [UserMetadata](agilicus_api/docs/UserMetadata.md)
 - [UserMetadataSpec](agilicus_api/docs/UserMetadataSpec.md)
 - [UserMetrics](agilicus_api/docs/UserMetrics.md)
 - [UserRequestInfo](agilicus_api/docs/UserRequestInfo.md)
 - [UserRequestInfoSpec](agilicus_api/docs/UserRequestInfoSpec.md)
 - [UserRequestInfoStatus](agilicus_api/docs/UserRequestInfoStatus.md)
 - [UserResourceAccessInfo](agilicus_api/docs/UserResourceAccessInfo.md)
 - [UserResourceAccessInfoStatus](agilicus_api/docs/UserResourceAccessInfoStatus.md)
 - [UserRoles](agilicus_api/docs/UserRoles.md)
 - [UserRolesForAnOrg](agilicus_api/docs/UserRolesForAnOrg.md)
 - [UserSessionIdentifiers](agilicus_api/docs/UserSessionIdentifiers.md)
 - [UserStatusEnum](agilicus_api/docs/UserStatusEnum.md)
 - [UserSummary](agilicus_api/docs/UserSummary.md)
 - [WebAuthNEnrollment](agilicus_api/docs/WebAuthNEnrollment.md)
 - [WebAuthNEnrollmentAnswer](agilicus_api/docs/WebAuthNEnrollmentAnswer.md)
 - [WebAuthNEnrollmentSpec](agilicus_api/docs/WebAuthNEnrollmentSpec.md)
 - [WebAuthNEnrollmentStatus](agilicus_api/docs/WebAuthNEnrollmentStatus.md)
 - [WellKnownIssuerInfo](agilicus_api/docs/WellKnownIssuerInfo.md)
 - [WhoamiRequest](agilicus_api/docs/WhoamiRequest.md)
 - [WhoamiResponse](agilicus_api/docs/WhoamiResponse.md)
 - [WorkloadConfiguration](agilicus_api/docs/WorkloadConfiguration.md)
 - [X509Certificate](agilicus_api/docs/X509Certificate.md)
 - [X509CertificateSpec](agilicus_api/docs/X509CertificateSpec.md)
 - [X509CertificateStatus](agilicus_api/docs/X509CertificateStatus.md)
 - [XSSSettings](agilicus_api/docs/XSSSettings.md)


## Documentation For Authorization


## token-valid

- **Type**: Bearer authentication (JWT)


## Author

dev@agilicus.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in agilicus_api.apis and agilicus_api.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from agilicus_api.api.default_api import DefaultApi`
- `from agilicus_api.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import agilicus_api
from agilicus_api.apis import *
from agilicus_api.models import *
```

